@@ -23,6 +23,7 @@ import (
 	"strconv"
 	"strings"
 
+	"k8s.io/minikube/cmd/minikube/cmd/flags"
 	"k8s.io/minikube/pkg/minikube/cluster"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/constants"
@@ -31,12 +32,13 @@ import (
 	"k8s.io/minikube/pkg/minikube/notify"
 	"k8s.io/minikube/pkg/minikube/out"
 	"k8s.io/minikube/pkg/minikube/reason"
+	"k8s.io/minikube/pkg/minikube/run"
 	"k8s.io/minikube/pkg/minikube/style"
 
-	"github.com/docker/machine/libmachine"
 	"github.com/olekukonko/tablewriter"
 	"github.com/olekukonko/tablewriter/tw"
 	"github.com/spf13/cobra"
+	"k8s.io/minikube/pkg/libmachine"
 
 	"k8s.io/klog/v2"
 )
@@ -52,15 +54,16 @@ var profileListCmd = &cobra.Command{
 	Short: "Lists all minikube profiles.",
 	Long:  "Lists all valid minikube profiles and detects all possible invalid profiles.",
 	Run: func(_ *cobra.Command, _ []string) {
+		options := flags.CommandOptions()
 		output := strings.ToLower(profileOutput)
 		out.SetJSON(output == "json")
-		go notify.MaybePrintUpdateTextFromGithub()
+		go notify.MaybePrintUpdateTextFromGithub(options)
 
 		switch output {
 		case "json":
-			printProfilesJSON()
+			printProfilesJSON(options)
 		case "table":
-			printProfilesTable()
+			printProfilesTable(options)
 		default:
 			exit.Message(reason.Usage, fmt.Sprintf("invalid output format: %s. Valid values: 'table', 'json'", profileOutput))
 		}
@@ -77,7 +80,7 @@ func listProfiles() (validProfiles, invalidProfiles []*config.Profile, err error
 	return validProfiles, invalidProfiles, err
 }
 
-func printProfilesTable() {
+func printProfilesTable(options *run.CommandOptions) {
 	validProfiles, invalidProfiles, err := listProfiles()
 
 	if err != nil {
@@ -88,12 +91,12 @@ func printProfilesTable() {
 		exit.Message(reason.UsageNoProfileRunning, "No minikube profile was found.")
 	}
 
-	updateProfilesStatus(validProfiles)
+	updateProfilesStatus(validProfiles, options)
 	renderProfilesTable(profilesToTableData(validProfiles))
 	warnInvalidProfiles(invalidProfiles)
 }
 
-func updateProfilesStatus(profiles []*config.Profile) {
+func updateProfilesStatus(profiles []*config.Profile, options *run.CommandOptions) {
 	if isLight {
 		for _, p := range profiles {
 			p.Status = "Skipped"
@@ -101,7 +104,7 @@ func updateProfilesStatus(profiles []*config.Profile) {
 		return
 	}
 
-	api, err := machine.NewAPIClient()
+	api, err := machine.NewAPIClient(options)
 	if err != nil {
 		klog.Errorf("failed to get machine api client %v", err)
 	}
@@ -178,13 +181,33 @@ func profilesToTableData(profiles []*config.Profile) [][]string {
 		if p.ActiveKubeContext {
 			k = "*"
 		}
+
+		var row []string
 		if isDetailed {
-			data = append(data, []string{p.Name, p.Config.Driver, p.Config.KubernetesConfig.ContainerRuntime,
-				cpIP, strconv.Itoa(cpPort), k8sVersion, p.Status, strconv.Itoa(len(p.Config.Nodes)), c, k})
+			row = []string{p.Name, p.Config.Driver, p.Config.KubernetesConfig.ContainerRuntime,
+				cpIP, strconv.Itoa(cpPort), k8sVersion, p.Status, strconv.Itoa(len(p.Config.Nodes)), c, k}
 		} else {
-			data = append(data, []string{p.Name, p.Config.Driver, p.Config.KubernetesConfig.ContainerRuntime,
-				cpIP, k8sVersion, p.Status, strconv.Itoa(len(p.Config.Nodes)), c, k})
+			row = []string{p.Name, p.Config.Driver, p.Config.KubernetesConfig.ContainerRuntime,
+				cpIP, k8sVersion, p.Status, strconv.Itoa(len(p.Config.Nodes)), c, k}
 		}
+
+		// Colorize row based on status
+		switch p.Status {
+		case "Running", "OK", "Configured":
+			// Green
+			for i, val := range row {
+				row[i] = style.Green + val + style.Reset
+			}
+		case "Stopped", "Paused", "Skipped":
+			// No color (default/white)
+		default:
+			// Red for everything else (Error, Misconfigured, Warning, etc)
+			for i, val := range row {
+				row[i] = style.Red + val + style.Reset
+			}
+		}
+
+		data = append(data, row)
 	}
 	return data
 }
@@ -205,9 +228,9 @@ func warnInvalidProfiles(invalidProfiles []*config.Profile) {
 	}
 }
 
-func printProfilesJSON() {
+func printProfilesJSON(options *run.CommandOptions) {
 	validProfiles, invalidProfiles, err := listProfiles()
-	updateProfilesStatus(validProfiles)
+	updateProfilesStatus(validProfiles, options)
 
 	var body = map[string]interface{}{}
 	if err == nil || config.IsNotExist(err) {
