@@ -21,6 +21,7 @@ import (
 	"io"
 	"log"
 	"os"
+	"slices"
 	"strings"
 
 	"golang.org/x/term"
@@ -44,9 +45,9 @@ func AskForYesNoConfirmation(s string, posResponses, negResponses []string) bool
 		}
 
 		switch r := strings.ToLower(strings.TrimSpace(response)); {
-		case containsString(posResponses, r):
+		case slices.Contains(posResponses, r):
 			return true
-		case containsString(negResponses, r):
+		case slices.Contains(negResponses, r):
 			return false
 		default:
 			out.Err("Please type yes or no:")
@@ -137,22 +138,6 @@ func AskForPasswordValue(s string) string {
 	return result
 }
 
-// posString returns the first index of element in slice.
-// If slice does not contain element, returns -1.
-func posString(slice []string, element string) int {
-	for index, elem := range slice {
-		if elem == element {
-			return index
-		}
-	}
-	return -1
-}
-
-// containsString returns true if slice contains element
-func containsString(slice []string, element string) bool {
-	return posString(slice, element) != -1
-}
-
 // AskForStaticValidatedValue asks for a single value to enter and check for valid input
 func AskForStaticValidatedValue(s string, validator func(s string) bool) string {
 	reader := bufio.NewReader(os.Stdin)
