@@ -22,17 +22,18 @@ import (
 	"os/exec"
 	"path/filepath"
 	"runtime"
-	"strings"
 	"testing"
+	"time"
 
-	"github.com/docker/machine/libmachine"
 	"github.com/google/go-cmp/cmp"
 	"github.com/otiai10/copy"
 	"github.com/spf13/viper"
+	"k8s.io/minikube/pkg/libmachine"
 
 	cmdcfg "k8s.io/minikube/cmd/minikube/cmd/config"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/localpath"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
 // exclude returns a list of strings, minus the excluded ones
@@ -87,6 +88,7 @@ func TestDeleteProfile(t *testing.T) {
 		{"partial-mach", "p8_partial_machine_config", []string{"p8_partial_machine_config"}},
 	}
 
+	options := &run.CommandOptions{}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			t.Setenv(localpath.MinikubeHome, td)
@@ -106,7 +108,7 @@ func TestDeleteProfile(t *testing.T) {
 			}
 
 			hostAndDirsDeleter = hostAndDirsDeleterMock
-			errs := DeleteProfiles([]*config.Profile{profile})
+			errs := DeleteProfiles([]*config.Profile{profile}, options)
 			if len(errs) > 0 {
 				HandleDeletionErrors(errs)
 				t.Errorf("Errors while deleting profiles: %v", errs)
@@ -197,7 +199,7 @@ func TestDeleteAllProfiles(t *testing.T) {
 	profiles := validProfiles
 	profiles = append(profiles, inValidProfiles...)
 	hostAndDirsDeleter = hostAndDirsDeleterMock
-	errs := DeleteProfiles(profiles)
+	errs := DeleteProfiles(profiles, &run.CommandOptions{})
 
 	if errs != nil {
 		t.Errorf("errors while deleting all profiles: %v", errs)
@@ -226,9 +228,6 @@ func TestDeleteAllProfiles(t *testing.T) {
 // then tries to execute the tryKillOne function on it;
 // if after tryKillOne the process still exists, we consider it a failure
 func TestTryKillOne(t *testing.T) {
-	if runtime.GOOS == "windows" {
-		t.Skip("skipping on windows")
-	}
 
 	var waitForSig = []byte(`
 package main
@@ -246,7 +245,7 @@ func main() {
 	done := make(chan struct{})
 	defer close(ch)
 
-	signal.Notify(ch, syscall.SIGHUP)
+	signal.Notify(ch, syscall.SIGTERM)
 	defer signal.Stop(ch)
 
 	go func() {
@@ -267,10 +266,12 @@ func main() {
 	processToKill := exec.Command("go", "run", tmpfile)
 	err := processToKill.Start()
 	if err != nil {
-		t.Fatalf("while execing child process: %v\n", err)
+		t.Fatalf("while executing child process: %v\n", err)
 	}
 	pid := processToKill.Process.Pid
 
+	originalIsMinikubeProcess := isMinikubeProcess
+	defer func() { isMinikubeProcess = originalIsMinikubeProcess }()
 	isMinikubeProcess = func(int) (bool, error) {
 		return true, nil
 	}
@@ -280,8 +281,104 @@ func main() {
 		t.Fatalf("while trying to kill child proc %d: %v\n", pid, err)
 	}
 
-	// waiting for process to exit
-	if err := processToKill.Wait(); !strings.Contains(err.Error(), "killed") {
-		t.Fatalf("unable to kill process: %v\n", err)
+	done := make(chan error, 1)
+	go func() { done <- processToKill.Wait() }()
+
+	var waitErr error
+	select {
+	case waitErr = <-done:
+		t.Logf("child process wait result: %v", waitErr)
+	case <-time.After(1 * time.Second):
+		t.Fatalf("timed out waiting for process %d to exit", pid)
+	}
+
+}
+
+// TestIsMinikubeProcess validates the process name matching logic using real OS processes.
+// It ensures that `isMinikubeProcess` correctly identifies Minikube-related processes
+// based on their binary name, which is critical for safe cleanup during `minikube delete`
+// and avoids accidentally killing unrelated user processes.
+func TestIsMinikubeProcess(t *testing.T) {
+	// 1. Write a simple Go program that waits for a signal (mimicking a long-running process)
+	var waitForSig = []byte(`
+package main
+
+import (
+	"os"
+	"os/signal"
+	"syscall"
+)
+
+func main() {
+	ch := make(chan os.Signal, 1)
+	signal.Notify(ch, syscall.SIGTERM)
+	<-ch
+}
+`)
+	td := t.TempDir()
+	srcFile := filepath.Join(td, "main.go")
+	if err := os.WriteFile(srcFile, waitForSig, 0o600); err != nil {
+		t.Fatalf("failed to write source: %v", err)
+	}
+
+	// 2. Build binaries with different names
+	// Case A: Name contains "minikube"
+	mkBin := filepath.Join(td, "fake-minikube")
+	if runtime.GOOS == "windows" {
+		mkBin += ".exe"
+	}
+	buildBinary(t, srcFile, mkBin)
+
+	// Case B: Name does NOT contain "minikube"
+	otherBin := filepath.Join(td, "other-process")
+	if runtime.GOOS == "windows" {
+		otherBin += ".exe"
+	}
+	buildBinary(t, srcFile, otherBin)
+
+	// 3. Run and verify
+	tests := []struct {
+		name       string
+		binaryPath string
+		want       bool
+	}{
+		{"minikube-process", mkBin, true},
+		{"other-process", otherBin, false},
+	}
+
+	for _, tc := range tests {
+		t.Run(tc.name, func(t *testing.T) {
+			cmd := exec.Command(tc.binaryPath)
+			if err := cmd.Start(); err != nil {
+				t.Fatalf("failed to start %s: %v", tc.name, err)
+			}
+			pid := cmd.Process.Pid
+			t.Logf("Started %s with pid %d", tc.name, pid)
+
+			defer func() {
+				_ = cmd.Process.Kill()
+				_ = cmd.Wait()
+			}()
+
+			// Give it a moment to start and register in OS
+			// (On some CI systems, checking too fast might fail or return partial info)
+			time.Sleep(100 * time.Millisecond)
+
+			got, err := isMinikubeProcess(pid)
+			if err != nil {
+				t.Errorf("isMinikubeProcess(%d) returned unexpected error: %v", pid, err)
+			}
+			if got != tc.want {
+				t.Errorf("isMinikubeProcess(%d) [%s] = %v; want %v", pid, tc.binaryPath, got, tc.want)
+			}
+		})
+	}
+}
+
+func buildBinary(t *testing.T, src, out string) {
+	t.Helper()
+	cmd := exec.Command("go", "build", "-o", out, src)
+	if output, err := cmd.CombinedOutput(); err != nil {
+		t.Fatalf("failed to build %s: %v\nOutput: %s", out, err, string(output))
 	}
 }
