@@ -28,9 +28,9 @@ import (
 	"sync"
 	"syscall"
 
-	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"k8s.io/klog/v2"
+	"k8s.io/minikube/cmd/minikube/cmd/flags"
 	"k8s.io/minikube/pkg/minikube/cluster"
 	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/detect"
@@ -72,15 +72,15 @@ func defaultMountOptions() []string {
 
 // placeholders for flag values
 var (
-	mountIP      string
-	mountPort    uint16
-	mountVersion string
-	mountType    string
-	isKill       bool
-	uid          string
-	gid          string
-	mSize        int
-	options      []string
+	mountIP           string
+	mountPort         uint16
+	mountVersion      string
+	mountType         string
+	isKill            bool
+	uid               string
+	gid               string
+	mSize             int
+	mountOptionsValue []string
 )
 
 // supportedFilesystems is a map of filesystem types to not warn against.
@@ -100,9 +100,11 @@ var mountCmd = &cobra.Command{
 		}
 
 		if len(args) != 1 {
-			exit.Message(reason.Usage, `Please specify the directory to be mounted: 
+			exit.Message(reason.Usage, `Please specify the directory to be mounted:
 	minikube mount <source directory>:<target directory>   (example: "/host-home:/vm-home")`)
 		}
+
+		options := flags.CommandOptions()
 		mountString := args[0]
 		idx := strings.LastIndex(mountString, ":")
 		if idx == -1 { // no ":" was present
@@ -125,7 +127,7 @@ var mountCmd = &cobra.Command{
 			debugVal = 1 // ufs.StartServer takes int debug param
 		}
 
-		co := mustload.Running(ClusterFlagValue())
+		co := mustload.Running(ClusterFlagValue(), options)
 		if co.CP.Host.Driver.DriverName() == driver.None {
 			exit.Message(reason.Usage, `'none' driver does not support 'minikube mount' command`)
 		}
@@ -177,7 +179,7 @@ var mountCmd = &cobra.Command{
 			Options: map[string]string{},
 		}
 
-		for _, o := range options {
+		for _, o := range mountOptionsValue {
 			if !strings.Contains(o, "=") {
 				cfg.Options[o] = ""
 				continue
@@ -265,7 +267,7 @@ func init() {
 	mountCmd.Flags().BoolVar(&isKill, "kill", false, "Kill the mount process spawned by minikube start")
 	mountCmd.Flags().StringVar(&uid, constants.MountUIDFlag, defaultMountUID, mountUIDDescription)
 	mountCmd.Flags().StringVar(&gid, constants.MountGIDFlag, defaultMountGID, mountGIDDescription)
-	mountCmd.Flags().StringSliceVar(&options, constants.MountOptionsFlag, defaultMountOptions(), mountOptionsDescription)
+	mountCmd.Flags().StringSliceVar(&mountOptionsValue, constants.MountOptionsFlag, defaultMountOptions(), mountOptionsDescription)
 	mountCmd.Flags().IntVar(&mSize, constants.MountMSizeFlag, defaultMountMSize, mountMSizeDescription)
 }
 
@@ -278,7 +280,7 @@ func getPort() (int, error) {
 
 	l, err := net.ListenTCP("tcp", addr)
 	if err != nil {
-		return -1, errors.Errorf("Error accessing port %d", addr.Port)
+		return -1, fmt.Errorf("Error accessing port %d", addr.Port)
 	}
 	defer l.Close()
 	return l.Addr().(*net.TCPAddr).Port, nil
@@ -315,7 +317,7 @@ func removePid(path string, pid string) error {
 	// we're reading the pids...
 	data, err := os.ReadFile(pidPath)
 	if err != nil {
-		return errors.Wrap(err, "readFile")
+		return fmt.Errorf("readFile: %w", err)
 	}
 
 	pids := []string{}
