@@ -26,6 +26,7 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 	"k8s.io/klog/v2"
+	"k8s.io/minikube/cmd/minikube/cmd/flags"
 	"k8s.io/minikube/pkg/minikube/exit"
 	"k8s.io/minikube/pkg/minikube/mustload"
 	"k8s.io/minikube/pkg/minikube/out"
@@ -44,6 +45,7 @@ var versionCmd = &cobra.Command{
 	Short: "Print the version of minikube",
 	Long:  `Print the version of minikube.`,
 	Run: func(_ *cobra.Command, _ []string) {
+		options := flags.CommandOptions()
 		minikubeVersion := version.GetVersion()
 		gitCommitID := version.GetGitCommitID()
 		data := map[string]interface{}{
@@ -52,7 +54,7 @@ var versionCmd = &cobra.Command{
 		}
 
 		if listComponentsVersions && !shortVersion {
-			co := mustload.Running(ClusterFlagValue())
+			co := mustload.Running(ClusterFlagValue(), options)
 			runner := co.CP.Runner
 			versionCMDS := map[string]*exec.Cmd{
 				"docker":      exec.Command("docker", "--version"),
