@@ -78,18 +78,21 @@ GCR_IMG=${GCR_REPO}:${KIC_VERSION}
 DH_IMG=${DH_REPO}:${KIC_VERSION}
 export KICBASE_IMAGE_REGISTRIES="${GCR_IMG} ${DH_IMG}"
 
-# Build a new kicbase image
-CIBUILD=yes make push-kic-base-image | tee kic-logs.txt
 
-# Abort with error message if above command failed
-ec=$?
-if [ $ec -gt 0 ]; then
-	if [ "$release" = false ]; then
-		gh pr comment ${ghprbPullId} --body "Hi ${ghprbPullAuthorLoginMention}, building a new kicbase image failed.
+if ! CIBUILD=yes make push-kic-base-image | tee kic-logs.txt; then
+    # Exit of `make` (PIPESTATUS[0]); fallback to 1 if unavailable
+    ec=${PIPESTATUS[0]:-1}
+
+    # Only comment on non-release; default release=false if unset
+    if [[ ${release:-false} != "true" ]]; then
+        body=$(cat << EOF
+Hi ${ghprbPullAuthorLoginMention}, building a new kicbase image failed.
 		See the logs at: https://storage.cloud.google.com/minikube-builds/logs/${ghprbPullId}/${ghprbActualCommit::7}/kic_image_build.txt
-		"
-	fi
-	exit $ec
+EOF
+)
+	    gh pr comment "${ghprbPullId}" --body "$body"
+    fi
+    exit "$ec"
 fi
 
 # Retrieve the sha from the new image
