@@ -49,8 +49,6 @@ make -j 16 \
   out/mkcmp \
   out/minikube_${DEB_VER}_amd64.deb \
   out/minikube_${DEB_VER}_arm64.deb \
-  out/docker-machine-driver-kvm2_$(make deb_version_base).deb \
-  out/docker-machine-driver-kvm2_${DEB_VER}_amd64.deb \
 && failed=$? || failed=$?
 
 BUILT_VERSION=$("out/minikube-$(go env GOOS)-$(go env GOARCH)" version)
