@@ -27,7 +27,7 @@ import (
 	"runtime/debug"
 	"strings"
 
-	"github.com/pkg/errors"
+	"errors"
 
 	"github.com/spf13/viper"
 	"k8s.io/minikube/pkg/minikube/constants"
@@ -152,15 +152,15 @@ func makePreload(cfg preloadCfg) error {
 	}()
 
 	if err := generateTarball(kv, cr, tf); err != nil {
-		return errors.Wrap(err, fmt.Sprintf("generating tarball for k8s version %s with %s", kv, cr))
+		return fmt.Errorf("%s: %w", fmt.Sprintf("generating tarball for k8s version %s with %s", kv, cr), err)
 	}
 
 	if *noUpload {
 		fmt.Printf("skip upload of %q\n", tf)
 		return nil
 	}
-	if err := uploadTarball(tf, kv); err != nil {
-		return errors.Wrap(err, fmt.Sprintf("uploading tarball for k8s version %s with %s", kv, cr))
+	if err := uploadTarballToGCS(tf, kv); err != nil {
+		return fmt.Errorf("%s: %w", fmt.Sprintf("uploading tarball for k8s version %s with %s", kv, cr), err)
 	}
 	return nil
 }
@@ -188,19 +188,35 @@ var verifyContainerdStorage = func() error {
 	if err != nil {
 		return fmt.Errorf("%v: %v:\n%s", cmd.Args, err, stderr.String())
 	}
-	var driver string
-	for _, line := range strings.Split(string(output), "\n") {
-		if strings.Contains(line, "snapshotter = ") {
-			driver = strings.Split(line, " = ")[1]
-			driver = strings.Trim(driver, "\"")
-		}
-	}
+	driver := parseContainerdSnapshotter(string(output))
 	if driver != containerdSnapshotter {
 		return fmt.Errorf("containerd snapshotter %s does not match requested %s", driver, containerdSnapshotter)
 	}
 	return nil
 }
 
+func parseContainerdSnapshotter(cfg string) string {
+	var driver string
+	for _, line := range strings.Split(cfg, "\n") {
+		line = strings.TrimSpace(line)
+		if !strings.HasPrefix(line, "snapshotter") { // e.g. snapshotter = "overlayfs" or snapshotter = 'overlayfs'
+			continue
+		}
+		parts := strings.SplitN(line, "=", 2)
+		if len(parts) != 2 {
+			continue
+		}
+		val := strings.Trim(strings.TrimSpace(parts[1]), "\"'")
+		if val == "" {
+			continue
+		}
+		if driver == "" {
+			driver = val
+		}
+	}
+	return driver
+}
+
 var verifyPodmanStorage = func() error {
 	cmd := exec.Command("docker", "exec", profile, "sudo", "podman", "info", "-f", "json")
 	var stderr bytes.Buffer
