@@ -58,5 +58,7 @@ func main() {
 	data := Data{StableVersion: stable}
 	klog.Infof("Hugo stable version: %s", stable)
 
-	update.Apply(schema, data)
+	if err := update.Apply(schema, data); err != nil {
+		klog.Fatalf("unable to apply update: %v", err)
+	}
 }
