@@ -56,5 +56,7 @@ func main() {
 
 	data := Data{Version: version, SHA: sha}
 
-	update.Apply(schema, data)
+	if err := update.Apply(schema, data); err != nil {
+		klog.Fatalf("unable to apply update: %v", err)
+	}
 }
