@@ -53,5 +53,7 @@ func main() {
 
 	data := Data{Version: version}
 
-	update.Apply(schema, data)
+	if err := update.Apply(schema, data); err != nil {
+		klog.Fatalf("unable to apply update: %v", err)
+	}
 }
