@@ -30,7 +30,7 @@ import (
 var schema = map[string]update.Item{
 	"pkg/minikube/assets/addons.go": {
 		Replace: map[string]string{
-			`marcnuri/yakd:.*`: `marcnuri/yakd:{{.Version}}@{{.SHA}}",`,
+			`manusa/yakd:.*`: `manusa/yakd:{{.Version}}@{{.SHA}}",`,
 		},
 	},
 }
@@ -49,12 +49,14 @@ func main() {
 		klog.Fatalf("Unable to get stable version: %v", err)
 	}
 	version := strings.TrimPrefix(stable.Tag, "v")
-	sha, err := update.GetImageSHA(fmt.Sprintf("docker.io/marcnuri/yakd:%s", version))
+	sha, err := update.GetImageSHA(fmt.Sprintf("ghcr.io/manusa/yakd:%s", version))
 	if err != nil {
 		klog.Fatalf("failed to get image SHA: %v", err)
 	}
 
 	data := Data{Version: version, SHA: sha}
 
-	update.Apply(schema, data)
+	if err := update.Apply(schema, data); err != nil {
+		klog.Fatalf("unable to apply update: %v", err)
+	}
 }
