@@ -20,6 +20,7 @@ import (
 	"testing"
 
 	"k8s.io/minikube/pkg/minikube/config"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
 func TestIsAddonValid(t *testing.T) {
@@ -48,39 +49,6 @@ func TestIsAddonValid(t *testing.T) {
 	}
 }
 
-func TestContains(t *testing.T) {
-	tests := []struct {
-		slice    []string
-		str      string
-		expected bool
-	}{
-		{
-			slice:    []string{},
-			str:      "test",
-			expected: false,
-		},
-		{
-			slice:    []string{"test", "test1"},
-			str:      "test1",
-			expected: true,
-		},
-		{
-			slice:    []string{"test", "test1"},
-			str:      "test2",
-			expected: false,
-		},
-	}
-
-	for _, test := range tests {
-		t.Run(test.str, func(t *testing.T) {
-			actual := contains(test.slice, test.str)
-			if test.expected != actual {
-				t.Fatalf("slice: %v\nstr: %v\nexpected: %v\nactual:%v\n", test.slice, test.str, test.expected, actual)
-			}
-		})
-	}
-}
-
 func TestIsKVMDriverForNVIDIA(t *testing.T) {
 	tests := []struct {
 		cc        *config.ClusterConfig
@@ -96,7 +64,7 @@ func TestIsKVMDriverForNVIDIA(t *testing.T) {
 	}
 
 	for _, tc := range tests {
-		err := isKVMDriverForNVIDIA(tc.cc, "", "")
+		err := isKVMDriverForNVIDIA(tc.cc, "", "", &run.CommandOptions{})
 		if gotError := (err != nil); gotError != tc.wantError {
 			t.Errorf("isKVMDriverForNVIDIA(%v) got error %t (%v), want error %t", tc.cc, gotError, err, tc.wantError)
 		}
