@@ -23,8 +23,9 @@ import (
 	"runtime"
 
 	"k8s.io/minikube/pkg/minikube/reason"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
-func ValidateHelper() error {
+func ValidateHelper(_ *run.CommandOptions) error {
 	return &Error{Kind: reason.Usage, Err: fmt.Errorf("vmnet-helper is not available on %q", runtime.GOOS)}
 }
