@@ -1,4 +1,4 @@
-//go:build linux
+//go:build linux && amd64
 
 /*
 Copyright 2016 The Kubernetes Authors All rights reserved.
@@ -23,8 +23,7 @@ import (
 	"fmt"
 	"text/template"
 
-	"github.com/docker/machine/libmachine/log"
-	"github.com/pkg/errors"
+	"k8s.io/minikube/pkg/libmachine/log"
 	"libvirt.org/go/libvirt"
 )
 
@@ -70,15 +69,8 @@ func closeDomain(dom *libvirt.Domain, conn *libvirt.Connect) error {
 func (d *Driver) defineDomain() (*libvirt.Domain, error) {
 	tmpl := template.Must(template.New("domain").Parse(domainTmpl))
 	var domainXML bytes.Buffer
-	dlog := struct {
-		Driver
-		ConsoleLogPath string
-	}{
-		Driver:         *d,
-		ConsoleLogPath: consoleLogPath(*d),
-	}
-	if err := tmpl.Execute(&domainXML, dlog); err != nil {
-		return nil, errors.Wrap(err, "executing domain xml")
+	if err := tmpl.Execute(&domainXML, d); err != nil {
+		return nil, fmt.Errorf("executing domain xml: %w", err)
 	}
 	conn, err := getConnection(d.ConnectionURI)
 	if err != nil {
@@ -93,7 +85,7 @@ func (d *Driver) defineDomain() (*libvirt.Domain, error) {
 	log.Infof("defining domain using XML: %v", domainXML.String())
 	dom, err := conn.DomainDefineXML(domainXML.String())
 	if err != nil {
-		return nil, errors.Wrapf(err, "error defining domain xml: %s", domainXML.String())
+		return nil, fmt.Errorf("error defining domain xml: %s: %w", domainXML.String(), err)
 	}
 
 	// save MAC address
