@@ -17,15 +17,15 @@ limitations under the License.
 package none
 
 import (
+	"encoding/json"
 	"fmt"
 	"os/exec"
 
-	"github.com/docker/machine/libmachine/drivers"
-	"github.com/docker/machine/libmachine/state"
-	"github.com/pkg/errors"
 	knet "k8s.io/apimachinery/pkg/util/net"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/drivers/common"
+	"k8s.io/minikube/pkg/libmachine/drivers"
+	"k8s.io/minikube/pkg/libmachine/state"
 	"k8s.io/minikube/pkg/minikube/bootstrapper/bsutil/kverify"
 	"k8s.io/minikube/pkg/minikube/command"
 	"k8s.io/minikube/pkg/minikube/constants"
@@ -47,9 +47,10 @@ var cleanupPaths = []string{
 type Driver struct {
 	*drivers.BaseDriver
 	*common.CommonDriver
-	URL     string
-	runtime cruntime.Manager
-	exec    command.Runner
+	URL              string
+	ContainerRuntime string
+	runtime          cruntime.Manager
+	exec             command.Runner
 }
 
 // Config is configuration for the None driver
@@ -72,8 +73,9 @@ func NewDriver(c Config) *Driver {
 			MachineName: c.MachineName,
 			StorePath:   c.StorePath,
 		},
-		runtime: runtime,
-		exec:    runner,
+		ContainerRuntime: c.ContainerRuntime,
+		runtime:          runtime,
+		exec:             runner,
 	}
 }
 
@@ -125,7 +127,7 @@ func (d *Driver) GetURL() (string, error) {
 
 // GetState returns the state that the host is in (running, stopped, etc)
 func (d *Driver) GetState() (state.State, error) {
-	hostname, port, err := kubeconfig.Endpoint(d.BaseDriver.MachineName, "")
+	hostname, port, err := kubeconfig.Endpoint(d.MachineName, "")
 	if err != nil {
 		klog.Warningf("unable to get port: %v", err)
 		port = constants.APIServerPort
@@ -154,25 +156,25 @@ func (d *Driver) Kill() error {
 	// First try to gracefully stop containers
 	containers, err := d.runtime.ListContainers(cruntime.ListContainersOptions{})
 	if err != nil {
-		return errors.Wrap(err, "containers")
+		return fmt.Errorf("containers: %w", err)
 	}
 	if len(containers) == 0 {
 		return nil
 	}
 	// Try to be graceful before sending SIGKILL everywhere.
 	if err := d.runtime.StopContainers(containers); err != nil {
-		return errors.Wrap(err, "stop")
+		return fmt.Errorf("stop: %w", err)
 	}
 
 	containers, err = d.runtime.ListContainers(cruntime.ListContainersOptions{})
 	if err != nil {
-		return errors.Wrap(err, "containers")
+		return fmt.Errorf("containers: %w", err)
 	}
 	if len(containers) == 0 {
 		return nil
 	}
 	if err := d.runtime.KillContainers(containers); err != nil {
-		return errors.Wrap(err, "kill")
+		return fmt.Errorf("kill: %w", err)
 	}
 	return nil
 }
@@ -180,7 +182,7 @@ func (d *Driver) Kill() error {
 // Remove a host, including any data which may have been written by it.
 func (d *Driver) Remove() error {
 	if err := d.Kill(); err != nil {
-		return errors.Wrap(err, "kill")
+		return fmt.Errorf("kill: %w", err)
 	}
 	klog.Infof("Removing: %s", cleanupPaths)
 	args := append([]string{"rm", "-rf"}, cleanupPaths...)
@@ -217,19 +219,69 @@ func (d *Driver) Stop() error {
 			klog.Warningf("couldn't force stop kubelet. will continue with stop anyways: %v", err)
 		}
 	}
-	containers, err := d.runtime.ListContainers(cruntime.ListContainersOptions{})
+	// Stop running containers
+	running, err := d.runtime.ListContainers(cruntime.ListContainersOptions{State: cruntime.Running})
 	if err != nil {
-		return errors.Wrap(err, "containers")
+		return fmt.Errorf("list running containers: %w", err)
 	}
-	if len(containers) > 0 {
-		if err := d.runtime.StopContainers(containers); err != nil {
-			return errors.Wrap(err, "stop containers")
+	if len(running) > 0 {
+		if err := d.runtime.StopContainers(running); err != nil {
+			return fmt.Errorf("stop running containers: %w", err)
+		}
+	}
+
+	// Stop paused containers
+	paused, err := d.runtime.ListContainers(cruntime.ListContainersOptions{State: cruntime.Paused})
+	if err != nil {
+		return fmt.Errorf("list paused containers: %w", err)
+	}
+	if len(paused) > 0 {
+		if err := d.runtime.StopContainers(paused); err != nil {
+			return fmt.Errorf("stop paused containers: %w", err)
 		}
 	}
 	klog.Infof("none driver is stopped!")
 	return nil
 }
 
+func (d *Driver) ensureRuntime() {
+	if d.ContainerRuntime == "" {
+		return
+	}
+	if d.runtime != nil && d.runtime.Name() == d.ContainerRuntime {
+		return
+	}
+	var current string
+	if d.runtime != nil {
+		current = d.runtime.Name()
+	}
+	klog.Infof("Updating runtime from %q to %q", current, d.ContainerRuntime)
+	r, err := cruntime.New(cruntime.Config{Type: d.ContainerRuntime, Runner: d.exec})
+	if err != nil {
+		klog.Warningf("unable to re-create container runtime: %v", err)
+		return
+	}
+	d.runtime = r
+}
+
+// for sake of Encapsulation implementing an interface that encoding/json package looks for.
+// will be called Load & NewHost funcs in pkg/minikube/machine/client.go
+// Other drivers dont need this special handling
+// because their "stop" only needs to know about VM and not runtime.
+func (d *Driver) UnmarshalJSON(data []byte) error {
+	type Alias Driver
+	aux := &struct {
+		*Alias
+	}{
+		Alias: (*Alias)(d),
+	}
+	if err := json.Unmarshal(data, &aux); err != nil {
+		return err
+	}
+	d.ensureRuntime()
+	return nil
+}
+
 // RunSSHCommandFromDriver implements direct ssh control to the driver
 func (d *Driver) RunSSHCommandFromDriver() error {
 	return fmt.Errorf("driver does not support ssh commands")
