@@ -24,7 +24,6 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"io"
 	"net"
 	"net/http"
 	"os"
@@ -35,12 +34,13 @@ import (
 	"syscall"
 	"time"
 
-	"github.com/docker/machine/libmachine/drivers"
-	"github.com/docker/machine/libmachine/log"
-	"github.com/docker/machine/libmachine/mcnutils"
-	"github.com/docker/machine/libmachine/ssh"
-	"github.com/docker/machine/libmachine/state"
-	"github.com/pkg/errors"
+	"errors"
+
+	"k8s.io/minikube/pkg/libmachine/drivers"
+	"k8s.io/minikube/pkg/libmachine/log"
+	"k8s.io/minikube/pkg/libmachine/mcnutils"
+	"k8s.io/minikube/pkg/libmachine/ssh"
+	"k8s.io/minikube/pkg/libmachine/state"
 
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/drivers/common"
@@ -52,6 +52,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/out"
 	"k8s.io/minikube/pkg/minikube/process"
 	"k8s.io/minikube/pkg/minikube/reason"
+	"k8s.io/minikube/pkg/minikube/run"
 	"k8s.io/minikube/pkg/minikube/style"
 )
 
@@ -62,6 +63,10 @@ const (
 	logFileName    = "vfkit.log"
 	serialFileName = "serial.log"
 	defaultSSHUser = "docker"
+
+	// Rosetta mount in the guest.
+	rosettaMountTag   = "minikube-rosetta"
+	rosettaMountPoint = "/mnt/minikube-rosetta"
 )
 
 // Driver is the machine driver for vfkit (Virtualization.framework)
@@ -77,16 +82,19 @@ type Driver struct {
 	Network        string        // "", "nat", "vmnet-shared"
 	MACAddress     string        // For network=nat, network=""
 	VmnetHelper    *vmnet.Helper // For network=vmnet-shared
+	Rosetta        bool          // Enable rosetta support
 }
 
-func NewDriver(hostName, storePath string) drivers.Driver {
+func NewDriver(hostName, storePath string, options *run.CommandOptions) drivers.Driver {
 	return &Driver{
 		BaseDriver: &drivers.BaseDriver{
 			SSHUser:     defaultSSHUser,
 			MachineName: hostName,
 			StorePath:   storePath,
 		},
-		CommonDriver: &common.CommonDriver{},
+		CommonDriver: &common.CommonDriver{
+			CommandOptions: *options,
+		},
 	}
 }
 
@@ -251,11 +259,16 @@ func (d *Driver) Start() error {
 		return err
 	}
 
-	log.Infof("Waiting for VM to start (ssh -p %d docker@%s)...", d.SSHPort, d.IPAddress)
-	if err := WaitForTCPWithDelay(fmt.Sprintf("%s:%d", d.IPAddress, d.SSHPort), time.Second); err != nil {
+	if err := common.WaitForSSHAccess(d); err != nil {
 		return err
 	}
 
+	if d.Rosetta {
+		if err := d.setupRosetta(); err != nil {
+			return err
+		}
+	}
+
 	if len(d.VirtiofsMounts) > 0 {
 		log.Infof("Setup virtiofs mounts ...")
 		if err := virtiofs.SetupMounts(d, d.VirtiofsMounts); err != nil {
@@ -326,6 +339,10 @@ func (d *Driver) startVfkit(socketPath string) error {
 
 	}
 
+	if d.Rosetta {
+		startCmd = append(startCmd, d.rosettaOptions()...)
+	}
+
 	log.Debugf("executing: vfkit %s", strings.Join(startCmd, " "))
 	os.Remove(d.sockfilePath())
 	cmd := exec.Command("vfkit", startCmd...)
@@ -347,19 +364,71 @@ func (d *Driver) startVfkit(socketPath string) error {
 	return process.WritePidfile(d.pidfilePath(), cmd.Process.Pid)
 }
 
+// rosettaOptions returns the vfkit command line options for Rosetta support.
+func (d *Driver) rosettaOptions() []string {
+	options := []string{
+		"rosetta",
+		"mountTag=" + rosettaMountTag,
+	}
+
+	// Try to install rosetta automatically for best user experience. The
+	// installation requires user interaction so we must skip it in
+	// non-interactive mode. If Rosetta is not installed vfkit will fail.
+	// For more info see https://support.apple.com/en-us/102527
+	if !d.CommandOptions.NonInteractive {
+		options = append(options, "install")
+	}
+
+	return []string{"--device", strings.Join(options, ",")}
+}
+
+func (d *Driver) setupRosetta() error {
+	// See https://docs.kernel.org/admin-guide/binfmt-misc.html
+	binfmt := strings.Join([]string{
+		// name
+		":rosetta",
+		// type: M (magic number matching), E (extension matching)
+		":M",
+		// offset (default 0)
+		":",
+		// magic
+		`:\x7fELF\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x3e\x00`,
+		// mask
+		`:\xff\xff\xff\xff\xff\xfe\xfe\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff`,
+		// interpreter
+		":" + filepath.Join(rosettaMountPoint, "rosetta"),
+		// flags: F (fix binary), C (credentials), or O (open binary)
+		":F",
+	}, "")
+
+	var b strings.Builder
+
+	fmt.Fprintf(&b, "set -e\n")
+	fmt.Fprintf(&b, "sudo mount binfmt_misc -t binfmt_misc /proc/sys/fs/binfmt_misc\n")
+	fmt.Fprintf(&b, "sudo mkdir -p %s\n", rosettaMountPoint)
+	fmt.Fprintf(&b, "sudo mount -t virtiofs %s %s\n", rosettaMountTag, rosettaMountPoint)
+	fmt.Fprintf(&b, "echo '%s' | sudo tee /proc/sys/fs/binfmt_misc/register\n", binfmt)
+
+	if _, err := drivers.RunSSHCommandFromDriver(d, b.String()); err != nil {
+		return fmt.Errorf("failed to setup rosetta: %w", err)
+	}
+
+	return nil
+}
+
 func (d *Driver) setupIP(mac string) error {
 	var err error
 	getIP := func() error {
 		d.IPAddress, err = common.GetIPAddressByMACAddress(mac)
 		if err != nil {
-			return errors.Wrap(err, "failed to get IP address")
+			return fmt.Errorf("failed to get IP address: %w", err)
 		}
 		return nil
 	}
 	// Implement a retry loop because IP address isn't added to dhcp leases file immediately
 	multiplier := 1
 	if detect.NestedVM() {
-		multiplier = 3 // will help with running in Free github action Macos VMs (takes 160+ retries on average)
+		multiplier = 3 // will help with running in Free github action Macos VMs (takes 112+ retries on average)
 	}
 	for i := 0; i < 60*multiplier; i++ {
 		log.Debugf("Attempt %d", i)
@@ -375,9 +444,9 @@ func (d *Driver) setupIP(mac string) error {
 		return nil
 	}
 	if !isBootpdError(err) {
-		return errors.Wrap(err, "IP address never found in dhcp leases file")
+		return fmt.Errorf("IP address never found in dhcp leases file: %w", err)
 	}
-	if unblockErr := firewall.UnblockBootpd(); unblockErr != nil {
+	if unblockErr := firewall.UnblockBootpd(&d.CommandOptions); unblockErr != nil {
 		klog.Errorf("failed unblocking bootpd from firewall: %v", unblockErr)
 		exit.Error(reason.IfBootpdFirewall, "ip not found", err)
 	}
@@ -440,11 +509,11 @@ func (d *Driver) Stop() error {
 func (d *Driver) Remove() error {
 	s, err := d.GetState()
 	if err != nil {
-		return errors.Wrap(err, "get state")
+		return fmt.Errorf("get state: %w", err)
 	}
 	if s == state.Running {
 		if err := d.Kill(); err != nil {
-			return errors.Wrap(err, "kill")
+			return fmt.Errorf("kill: %w", err)
 		}
 	}
 	return nil
@@ -657,19 +726,3 @@ func (d *Driver) SetVFKitState(s string) error {
 	log.Infof("Set vfkit state: %+v", vmstate)
 	return nil
 }
-
-func WaitForTCPWithDelay(addr string, duration time.Duration) error {
-	for {
-		conn, err := net.Dial("tcp", addr)
-		if err != nil {
-			continue
-		}
-		defer conn.Close()
-		if _, err := conn.Read(make([]byte, 1)); err != nil && err != io.EOF {
-			time.Sleep(duration)
-			continue
-		}
-		break
-	}
-	return nil
-}
