@@ -17,27 +17,27 @@ limitations under the License.
 package gvisor
 
 import (
+	"fmt"
 	"log"
 	"os"
 	"path/filepath"
 
-	"github.com/docker/machine/libmachine/mcnutils"
-	"github.com/pkg/errors"
+	"k8s.io/minikube/pkg/libmachine/mcnutils"
 )
 
 // Disable reverts containerd config files and restarts containerd
 func Disable() error {
 	log.Print("Disabling gvisor...")
 	if err := os.Remove(filepath.Join(nodeDir, containerdConfigPath)); err != nil {
-		return errors.Wrapf(err, "removing %s", containerdConfigPath)
+		return fmt.Errorf("removing %s: %w", containerdConfigPath, err)
 	}
 	log.Printf("Restoring default config.toml at %s", containerdConfigPath)
 	if err := mcnutils.CopyFile(filepath.Join(nodeDir, containerdConfigBackupPath), filepath.Join(nodeDir, containerdConfigPath)); err != nil {
-		return errors.Wrap(err, "reverting back to default config.toml")
+		return fmt.Errorf("reverting back to default config.toml: %w", err)
 	}
 	// restart containerd
 	if err := restartContainerd(); err != nil {
-		return errors.Wrap(err, "restarting containerd")
+		return fmt.Errorf("restarting containerd: %w", err)
 	}
 	log.Print("Successfully disabled gvisor")
 	return nil
