@@ -143,10 +143,14 @@ func TestReadConfig(t *testing.T) {
 }
 
 func TestWriteConfig(t *testing.T) {
-	configFile, err := os.CreateTemp("/tmp", "configTest")
+	tmpDir := t.TempDir()
+	configFile, err := os.CreateTemp(tmpDir, "configTest")
 	if err != nil {
 		t.Fatalf("Error not expected but got %v", err)
 	}
+	if err := configFile.Close(); err != nil {
+		t.Fatalf("failed to close temp file: %v", err)
+	}
 
 	cfg := map[string]interface{}{
 		"driver":               "test-driver",
@@ -160,7 +164,6 @@ func TestWriteConfig(t *testing.T) {
 	if err != nil {
 		t.Fatalf("Error not expected but got %v", err)
 	}
-	defer os.Remove(configFile.Name())
 
 	mkConfig, err := ReadConfig(configFile.Name())
 	if err != nil {
