@@ -21,6 +21,19 @@ package constants
 // ValidKubernetesVersions is a list of Kubernetes versions in order from newest to oldest
 // This is used when outputting Kubernetes versions and to select the latest patch version when unspecified
 var ValidKubernetesVersions = []string{
+	"v1.36.0-alpha.1",
+	"v1.35.1",
+	"v1.35.0",
+	"v1.35.0-rc.1",
+	"v1.35.0-rc.0",
+	"v1.35.0-beta.0",
+	"v1.35.0-alpha.3",
+	"v1.35.0-alpha.2",
+	"v1.35.0-alpha.1",
+	"v1.34.4",
+	"v1.34.3",
+	"v1.34.2",
+	"v1.34.1",
 	"v1.34.0",
 	"v1.34.0-rc.2",
 	"v1.34.0-rc.1",
@@ -29,6 +42,10 @@ var ValidKubernetesVersions = []string{
 	"v1.34.0-alpha.3",
 	"v1.34.0-alpha.2",
 	"v1.34.0-alpha.1",
+	"v1.33.8",
+	"v1.33.7",
+	"v1.33.6",
+	"v1.33.5",
 	"v1.33.4",
 	"v1.33.3",
 	"v1.33.2",
@@ -40,6 +57,10 @@ var ValidKubernetesVersions = []string{
 	"v1.33.0-alpha.3",
 	"v1.33.0-alpha.2",
 	"v1.33.0-alpha.1",
+	"v1.32.12",
+	"v1.32.11",
+	"v1.32.10",
+	"v1.32.9",
 	"v1.32.8",
 	"v1.32.7",
 	"v1.32.6",
@@ -56,6 +77,8 @@ var ValidKubernetesVersions = []string{
 	"v1.32.0-alpha.3",
 	"v1.32.0-alpha.2",
 	"v1.32.0-alpha.1",
+	"v1.31.14",
+	"v1.31.13",
 	"v1.31.12",
 	"v1.31.11",
 	"v1.31.10",
