@@ -26,8 +26,6 @@ import (
 	"time"
 
 	"github.com/blang/semver/v4"
-	"github.com/juju/mutex/v2"
-	"github.com/pkg/errors"
 
 	"k8s.io/klog/v2"
 
@@ -38,11 +36,33 @@ import (
 	"k8s.io/minikube/pkg/util/lock"
 )
 
+func newAuxUnthealthyError(path string) error {
+	return fmt.Errorf(`failed to execute auxiliary version command "%s --version"`, path)
+}
+
+func newAuxNotFoundError(name, path string) error {
+	return fmt.Errorf("auxiliary driver %s not found in path %s", name, path)
+}
+
+// ErrAuxDriverVersionCommandFailed indicates the aux driver 'version' command failed to run
+var ErrAuxDriverVersionCommandFailed error
+
+// ErrAuxDriverVersionNotinPath was not found in PATH
+var ErrAuxDriverVersionNotinPath error
+
 // InstallOrUpdate downloads driver if it is not present, or updates it if there's a newer version
-func InstallOrUpdate(name string, directory string, v semver.Version, interactive bool, autoUpdate bool) error {
-	if name != driver.KVM2 && name != driver.HyperKit {
+// this is currently only used for hyperkit driver on macOS
+func InstallOrUpdate(name string, directory string, interactive bool, autoUpdate bool) error {
+	if name != driver.HyperKit {
 		return nil
 	}
+	// v1.37.0 was the last release that we built hyperkit driver https://github.com/kubernetes/minikube/issues/21940
+	// this will be used till we completely remove hyperkit driver support
+	v, err := semver.Make("1.37.0")
+	out.WarningT("Hyperkit driver will be removed in the next minikube release, we have other drivers that work on macOS such as docker or qemu, vfkit. Please consider switching to one of them. For more information, please visit: https://minikube.sigs.k8s.io/docs/drivers/hyperkit/")
+	if err != nil {
+		return fmt.Errorf("can't parse version: %w", err)
+	}
 
 	executable := fmt.Sprintf("docker-machine-driver-%s", name)
 
@@ -50,9 +70,9 @@ func InstallOrUpdate(name string, directory string, v semver.Version, interactiv
 	spec := lock.PathMutexSpec(executable)
 	spec.Timeout = 10 * time.Minute
 	klog.Infof("acquiring lock: %+v", spec)
-	releaser, err := mutex.Acquire(spec)
+	releaser, err := lock.Acquire(spec)
 	if err != nil {
-		return errors.Wrapf(err, "unable to acquire lock for %+v", spec)
+		return fmt.Errorf("unable to acquire lock for %+v: %w", spec, err)
 	}
 	defer releaser.Release()
 
@@ -65,7 +85,14 @@ func InstallOrUpdate(name string, directory string, v semver.Version, interactiv
 			return err
 		}
 	}
-	return fixDriverPermissions(name, path, interactive)
+	if err := fixDriverPermissions(name, path, interactive); err != nil {
+		return err
+	}
+
+	if _, err := validateDriver(executable, minAcceptableDriverVersion(name, v)); err != nil {
+		return err
+	}
+	return nil
 }
 
 // fixDriverPermissions fixes the permissions on a driver
@@ -106,7 +133,7 @@ func fixDriverPermissions(name string, path string, interactive bool) error {
 		klog.Infof("running: %v", c.Args)
 		err := c.Run()
 		if err != nil {
-			return errors.Wrapf(err, "%v", c.Args)
+			return fmt.Errorf("%v: %w", c.Args, err)
 		}
 	}
 	return nil
@@ -117,12 +144,17 @@ func validateDriver(executable string, v semver.Version) (string, error) {
 	klog.Infof("Validating %s, PATH=%s", executable, os.Getenv("PATH"))
 	path, err := exec.LookPath(executable)
 	if err != nil {
-		return path, err
+		klog.Warningf("driver not in path : %s, %v", path, err.Error())
+		ErrAuxDriverVersionNotinPath = newAuxNotFoundError(executable, path)
+		return path, ErrAuxDriverVersionNotinPath
 	}
 
-	output, err := exec.Command(path, "version").Output()
+	cmd := exec.Command(path, "version")
+	output, err := cmd.CombinedOutput()
 	if err != nil {
-		return path, err
+		klog.Warningf("%s failed: %v: %s", cmd, err, output)
+		ErrAuxDriverVersionCommandFailed = newAuxUnthealthyError(path)
+		return path, ErrAuxDriverVersionCommandFailed
 	}
 
 	ev := extractDriverVersion(string(output))
@@ -132,7 +164,7 @@ func validateDriver(executable string, v semver.Version) (string, error) {
 
 	driverVersion, err := semver.Make(ev)
 	if err != nil {
-		return path, errors.Wrap(err, "can't parse driver version")
+		return path, fmt.Errorf("can't parse driver version: %w", err)
 	}
 	klog.Infof("%s version is %s", path, driverVersion)
 
