@@ -17,15 +17,16 @@ limitations under the License.
 package image
 
 import (
+	"fmt"
 	"os"
 	"path/filepath"
 	"time"
 
+	"errors"
+
 	"github.com/google/go-containerregistry/pkg/name"
 	v1 "github.com/google/go-containerregistry/pkg/v1"
 	"github.com/google/go-containerregistry/pkg/v1/tarball"
-	"github.com/juju/mutex/v2"
-	"github.com/pkg/errors"
 	"golang.org/x/sync/errgroup"
 	"k8s.io/klog/v2"
 	"k8s.io/minikube/pkg/minikube/detect"
@@ -61,8 +62,8 @@ func DeleteFromCacheDir(images []string) error {
 // SaveToDir will cache images on the host
 //
 // The cache directory currently caches images using the imagename_tag
-// For example, k8s.gcr.io/kube-addon-manager:v6.5 would be
-// stored at $CACHE_DIR/k8s.gcr.io/kube-addon-manager_v6.5
+// For example, registry.k8s.io/kube-addon-manager:v6.5 would be
+// stored at $CACHE_DIR/registry.k8s.io/kube-addon-manager_v6.5
 func SaveToDir(images []string, cacheDir string, overwrite bool) error {
 	var g errgroup.Group
 	for _, image := range images {
@@ -75,14 +76,14 @@ func SaveToDir(images []string, cacheDir string, overwrite bool) error {
 					out.WarningT("The image '{{.imageName}}' was not found; unable to add it to cache.", out.V{"imageName": image})
 					return nil
 				}
-				return errors.Wrapf(err, "caching image %q", dst)
+				return fmt.Errorf("caching image %q: %w", dst, err)
 			}
 			klog.Infof("save to tar file %s -> %s succeeded", image, dst)
 			return nil
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "caching images")
+		return fmt.Errorf("caching images: %w", err)
 	}
 	klog.Infoln("Successfully saved all images to host disk.")
 	return nil
@@ -99,15 +100,15 @@ func saveToTarFile(iname, rawDest string, overwrite bool) error {
 	// OS-specific mangling of destination path
 	dst, err := localpath.DstPath(rawDest)
 	if err != nil {
-		return errors.Wrap(err, "getting destination path")
+		return fmt.Errorf("getting destination path: %w", err)
 	}
 
 	spec := lock.PathMutexSpec(dst)
 	spec.Timeout = 10 * time.Minute
 	klog.Infof("acquiring lock: %+v", spec)
-	releaser, err := mutex.Acquire(spec)
+	releaser, err := lock.Acquire(spec)
 	if err != nil {
-		return errors.Wrapf(err, "unable to acquire lock for %+v", spec)
+		return fmt.Errorf("unable to acquire lock for %+v: %w", spec, err)
 	}
 	defer releaser.Release()
 
@@ -117,16 +118,16 @@ func saveToTarFile(iname, rawDest string, overwrite bool) error {
 	}
 
 	if err := os.MkdirAll(filepath.Dir(dst), 0777); err != nil {
-		return errors.Wrapf(err, "making cache image directory: %s", dst)
+		return fmt.Errorf("making cache image directory: %s: %w", dst, err)
 	}
 
 	// use given short name
 	ref, err := name.ParseReference(iname, name.WeakValidation)
 	if err != nil {
-		return errors.Wrapf(err, "parsing image ref name for %s", iname)
+		return fmt.Errorf("parsing image ref name for %s: %w", iname, err)
 	}
 	if ref == nil {
-		return errors.Wrapf(err, "nil reference for %s", iname)
+		return fmt.Errorf("nil reference for %s: %w", iname, err)
 	}
 
 	img, cname, err := retrieveImage(ref, iname)
@@ -135,17 +136,17 @@ func saveToTarFile(iname, rawDest string, overwrite bool) error {
 		return errCacheImageDoesntExist
 	}
 	if img == nil {
-		return errors.Wrapf(err, "nil image for %s", iname)
+		return fmt.Errorf("nil image for %s: %w", iname, err)
 	}
 
 	if cname != iname {
 		// use new canonical name
 		ref, err = name.ParseReference(cname, name.WeakValidation)
 		if err != nil {
-			return errors.Wrapf(err, "parsing image ref name for %s", cname)
+			return fmt.Errorf("parsing image ref name for %s: %w", cname, err)
 		}
 		if ref == nil {
-			return errors.Wrapf(err, "nil reference for %s", cname)
+			return fmt.Errorf("nil reference for %s: %w", cname, err)
 		}
 	}
 
@@ -177,15 +178,15 @@ func writeImage(img v1.Image, dst string, ref name.Reference) error {
 
 	err = tarball.Write(ref, img, f)
 	if err != nil {
-		return errors.Wrap(err, "write")
+		return fmt.Errorf("write: %w", err)
 	}
 	err = f.Close()
 	if err != nil {
-		return errors.Wrap(err, "close")
+		return fmt.Errorf("close: %w", err)
 	}
 	err = os.Rename(f.Name(), dst)
 	if err != nil {
-		return errors.Wrap(err, "rename")
+		return fmt.Errorf("rename: %w", err)
 	}
 	return nil
 }
