@@ -31,13 +31,12 @@ import (
 
 	"github.com/docker/docker/client"
 	"github.com/docker/go-units"
-	"github.com/docker/machine/libmachine/state"
 	"github.com/olekukonko/tablewriter"
 	"github.com/olekukonko/tablewriter/tw"
-	"github.com/pkg/errors"
 	"golang.org/x/sync/errgroup"
 	"gopkg.in/yaml.v2"
 	"k8s.io/klog/v2"
+	"k8s.io/minikube/pkg/libmachine/state"
 	"k8s.io/minikube/pkg/minikube/assets"
 	"k8s.io/minikube/pkg/minikube/bootstrapper"
 	"k8s.io/minikube/pkg/minikube/command"
@@ -47,6 +46,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/image"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/out"
+	"k8s.io/minikube/pkg/minikube/run"
 	"k8s.io/minikube/pkg/minikube/vmpath"
 )
 
@@ -63,11 +63,11 @@ var saveRoot = path.Join(vmpath.GuestPersistentDir, "images")
 func CacheImagesForBootstrapper(imageRepository, version string) error {
 	images, err := bootstrapper.GetCachedImageList(imageRepository, version)
 	if err != nil {
-		return errors.Wrap(err, "cached images list")
+		return fmt.Errorf("cached images list: %w", err)
 	}
 
 	if err := image.SaveToDir(images, detect.ImageCacheDir(), false); err != nil {
-		return errors.Wrap(err, "Caching images")
+		return fmt.Errorf("Caching images: %w", err)
 	}
 
 	return nil
@@ -77,7 +77,7 @@ func CacheImagesForBootstrapper(imageRepository, version string) error {
 func LoadCachedImages(cc *config.ClusterConfig, runner command.Runner, imgs []string, cacheDir string, overwrite bool) error {
 	cr, err := cruntime.New(cruntime.Config{Type: cc.KubernetesConfig.ContainerRuntime, Runner: runner})
 	if err != nil {
-		return errors.Wrap(err, "runtime")
+		return fmt.Errorf("runtime: %w", err)
 	}
 
 	// Skip loading images if images already exist
@@ -119,7 +119,7 @@ func LoadCachedImages(cc *config.ClusterConfig, runner command.Runner, imgs []st
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "LoadCachedImages")
+		return fmt.Errorf("LoadCachedImages: %w", err)
 	}
 	klog.Infoln("Successfully loaded all cached images")
 	return nil
@@ -180,31 +180,31 @@ func LoadLocalImages(cc *config.ClusterConfig, runner command.Runner, images []s
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "loading images")
+		return fmt.Errorf("loading images: %w", err)
 	}
 	klog.Infoln("Successfully loaded all images")
 	return nil
 }
 
 // CacheAndLoadImages caches and loads images to all profiles
-func CacheAndLoadImages(images []string, profiles []*config.Profile, overwrite bool) error {
+func CacheAndLoadImages(images []string, profiles []*config.Profile, overwrite bool, options *run.CommandOptions) error {
 	if len(images) == 0 {
 		return nil
 	}
 
 	// This is the most important thing
 	if err := image.SaveToDir(images, detect.ImageCacheDir(), overwrite); err != nil {
-		return errors.Wrap(err, "save to dir")
+		return fmt.Errorf("save to dir: %w", err)
 	}
 
-	return DoLoadImages(images, profiles, detect.ImageCacheDir(), overwrite)
+	return DoLoadImages(images, profiles, detect.ImageCacheDir(), overwrite, options)
 }
 
 // DoLoadImages loads images to all profiles
-func DoLoadImages(images []string, profiles []*config.Profile, cacheDir string, overwrite bool) error {
-	api, err := NewAPIClient()
+func DoLoadImages(images []string, profiles []*config.Profile, cacheDir string, overwrite bool, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "api")
+		return fmt.Errorf("api: %w", err)
 	}
 	defer api.Close()
 
@@ -280,7 +280,7 @@ func transferAndLoadCachedImage(cr command.Runner, k8s config.KubernetesConfig,
 func transferAndLoadImage(cr command.Runner, k8s config.KubernetesConfig, src string, imgName string) error {
 	r, err := cruntime.New(cruntime.Config{Type: k8s.ContainerRuntime, Runner: cr})
 	if err != nil {
-		return errors.Wrap(err, "runtime")
+		return fmt.Errorf("runtime: %w", err)
 	}
 
 	if err := removeExistingImage(r, src, imgName); err != nil {
@@ -296,7 +296,7 @@ func transferAndLoadImage(cr command.Runner, k8s config.KubernetesConfig, src st
 	dst := path.Join(loadRoot, filename)
 	f, err := assets.NewFileAsset(src, loadRoot, filename, "0644")
 	if err != nil {
-		return errors.Wrapf(err, "creating copyable file asset: %s", filename)
+		return fmt.Errorf("creating copyable file asset: %s: %w", filename, err)
 	}
 	defer func() {
 		if err := f.Close(); err != nil {
@@ -305,7 +305,7 @@ func transferAndLoadImage(cr command.Runner, k8s config.KubernetesConfig, src st
 	}()
 
 	if err := cr.Copy(f); err != nil {
-		return errors.Wrap(err, "transferring cached image")
+		return fmt.Errorf("transferring cached image: %w", err)
 	}
 
 	loadImageLock.Lock()
@@ -316,7 +316,7 @@ func transferAndLoadImage(cr command.Runner, k8s config.KubernetesConfig, src st
 		if strings.Contains(err.Error(), "ctr: image might be filtered out") {
 			out.WarningT("The image '{{.imageName}}' does not match arch of the container runtime, use a multi-arch image instead", out.V{"imageName": imgName})
 		}
-		return errors.Wrapf(err, "%s load %s", r.Name(), dst)
+		return fmt.Errorf("%s load %s: %w", r.Name(), dst, err)
 	}
 
 	klog.Infof("Transferred and loaded %s from cache", src)
@@ -337,7 +337,7 @@ func removeExistingImage(r cruntime.Manager, src string, imgName string) error {
 
 	errStr := strings.ToLower(err.Error())
 	if !strings.Contains(errStr, "no such image") && !strings.Contains(errStr, "unable to remove the image") {
-		return errors.Wrap(err, "removing image")
+		return fmt.Errorf("removing image: %w", err)
 	}
 
 	return nil
@@ -361,7 +361,7 @@ func SaveCachedImages(cc *config.ClusterConfig, runner command.Runner, images []
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "saving cached images")
+		return fmt.Errorf("saving cached images: %w", err)
 	}
 	klog.Infoln("Successfully saved all cached images")
 	return nil
@@ -377,26 +377,26 @@ func SaveLocalImages(cc *config.ClusterConfig, runner command.Runner, images []s
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "saving images")
+		return fmt.Errorf("saving images: %w", err)
 	}
 	klog.Infoln("Successfully saved all images")
 	return nil
 }
 
 // SaveAndCacheImages saves images from all profiles into the cache
-func SaveAndCacheImages(images []string, profiles []*config.Profile) error {
+func SaveAndCacheImages(images []string, profiles []*config.Profile, options *run.CommandOptions) error {
 	if len(images) == 0 {
 		return nil
 	}
 
-	return DoSaveImages(images, "", profiles, detect.ImageCacheDir())
+	return DoSaveImages(images, "", profiles, detect.ImageCacheDir(), options)
 }
 
 // DoSaveImages saves images from all profiles
-func DoSaveImages(images []string, output string, profiles []*config.Profile, cacheDir string) error {
-	api, err := NewAPIClient()
+func DoSaveImages(images []string, output string, profiles []*config.Profile, cacheDir string, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "api")
+		return fmt.Errorf("api: %w", err)
 	}
 	defer api.Close()
 
@@ -471,7 +471,7 @@ func transferAndSaveCachedImage(cr command.Runner, k8s config.KubernetesConfig,
 func transferAndSaveImage(cr command.Runner, k8s config.KubernetesConfig, dst string, imgName string) error {
 	r, err := cruntime.New(cruntime.Config{Type: k8s.ContainerRuntime, Runner: cr})
 	if err != nil {
-		return errors.Wrap(err, "runtime")
+		return fmt.Errorf("runtime: %w", err)
 	}
 	found := false
 	// the reason why we are doing this is that
@@ -501,7 +501,7 @@ func transferAndSaveImage(cr command.Runner, k8s config.KubernetesConfig, dst st
 
 	f, err := assets.NewFileAsset(dst, saveRoot, filename, "0644")
 	if err != nil {
-		return errors.Wrapf(err, "creating copyable file asset: %s", filename)
+		return fmt.Errorf("creating copyable file asset: %s: %w", filename, err)
 	}
 	defer func() {
 		if err := f.Close(); err != nil {
@@ -516,11 +516,11 @@ func transferAndSaveImage(cr command.Runner, k8s config.KubernetesConfig, dst st
 	}
 	err = r.SaveImage(imgName, src)
 	if err != nil {
-		return errors.Wrapf(err, "%s save %s", r.Name(), src)
+		return fmt.Errorf("%s save %s: %w", r.Name(), src, err)
 	}
 
 	if err := cr.CopyFrom(f); err != nil {
-		return errors.Wrap(err, "transferring cached image")
+		return fmt.Errorf("transferring cached image: %w", err)
 	}
 
 	klog.Infof("Transferred and saved %s to cache", dst)
@@ -545,17 +545,17 @@ func pullImages(crMgr cruntime.Manager, imgs []string) error {
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "error pulling images")
+		return fmt.Errorf("error pulling images: %w", err)
 	}
 	klog.Infoln("Successfully pulled images")
 	return nil
 }
 
 // PullImages pulls images to all nodes in profile
-func PullImages(images []string, profile *config.Profile) error {
-	api, err := NewAPIClient()
+func PullImages(images []string, profile *config.Profile, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "error creating api client")
+		return fmt.Errorf("error creating api client: %w", err)
 	}
 	defer api.Close()
 
@@ -567,7 +567,7 @@ func PullImages(images []string, profile *config.Profile) error {
 	c, err := config.Load(pName)
 	if err != nil {
 		klog.Errorf("Failed to load profile %q: %v", pName, err)
-		return errors.Wrapf(err, "error loading config for profile :%v", pName)
+		return fmt.Errorf("error loading config for profile :%v: %w", pName, err)
 	}
 
 	for _, n := range c.Nodes {
@@ -591,7 +591,7 @@ func PullImages(images []string, profile *config.Profile) error {
 			}
 			crMgr, err := cruntime.New(cruntime.Config{Type: c.KubernetesConfig.ContainerRuntime, Runner: runner})
 			if err != nil {
-				return errors.Wrap(err, "error creating container runtime")
+				return fmt.Errorf("error creating container runtime: %w", err)
 			}
 			err = pullImages(crMgr, images)
 			if err != nil {
@@ -626,17 +626,17 @@ func removeImages(crMgr cruntime.Manager, imgs []string) error {
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "error removing images")
+		return fmt.Errorf("error removing images: %w", err)
 	}
 	klog.Infoln("Successfully removed images")
 	return nil
 }
 
 // RemoveImages removes images from all nodes in profile
-func RemoveImages(images []string, profile *config.Profile) error {
-	api, err := NewAPIClient()
+func RemoveImages(images []string, profile *config.Profile, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "error creating api client")
+		return fmt.Errorf("error creating api client: %w", err)
 	}
 	defer api.Close()
 
@@ -648,7 +648,7 @@ func RemoveImages(images []string, profile *config.Profile) error {
 	c, err := config.Load(pName)
 	if err != nil {
 		klog.Errorf("Failed to load profile %q: %v", pName, err)
-		return errors.Wrapf(err, "error loading config for profile :%v", pName)
+		return fmt.Errorf("error loading config for profile :%v: %w", pName, err)
 	}
 
 	for _, n := range c.Nodes {
@@ -672,7 +672,7 @@ func RemoveImages(images []string, profile *config.Profile) error {
 			}
 			crMgr, err := cruntime.New(cruntime.Config{Type: c.KubernetesConfig.ContainerRuntime, Runner: runner})
 			if err != nil {
-				return errors.Wrap(err, "error creating container runtime")
+				return fmt.Errorf("error creating container runtime: %w", err)
 			}
 			err = removeImages(crMgr, images)
 			if err != nil {
@@ -691,10 +691,10 @@ func RemoveImages(images []string, profile *config.Profile) error {
 }
 
 // ListImages lists images on all nodes in profile
-func ListImages(profile *config.Profile, format string) error {
-	api, err := NewAPIClient()
+func ListImages(profile *config.Profile, format string, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "error creating api client")
+		return fmt.Errorf("error creating api client: %w", err)
 	}
 	defer api.Close()
 
@@ -703,7 +703,7 @@ func ListImages(profile *config.Profile, format string) error {
 	c, err := config.Load(pName)
 	if err != nil {
 		klog.Errorf("Failed to load profile %q: %v", pName, err)
-		return errors.Wrapf(err, "error loading config for profile :%v", pName)
+		return fmt.Errorf("error loading config for profile :%v: %w", pName, err)
 	}
 
 	imageListsFromNodes := [][]cruntime.ListImage{}
@@ -728,7 +728,7 @@ func ListImages(profile *config.Profile, format string) error {
 			}
 			cr, err := cruntime.New(cruntime.Config{Type: c.KubernetesConfig.ContainerRuntime, Runner: runner})
 			if err != nil {
-				return errors.Wrap(err, "error creating container runtime")
+				return fmt.Errorf("error creating container runtime: %w", err)
 			}
 			list, err := cr.ListImages(cruntime.ListImagesOptions{})
 			if err != nil {
@@ -860,10 +860,10 @@ func renderImagesTable(images [][]string) {
 }
 
 // TagImage tags image in all nodes in profile
-func TagImage(profile *config.Profile, source string, target string) error {
-	api, err := NewAPIClient()
+func TagImage(profile *config.Profile, source string, target string, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "error creating api client")
+		return fmt.Errorf("error creating api client: %w", err)
 	}
 	defer api.Close()
 
@@ -875,7 +875,7 @@ func TagImage(profile *config.Profile, source string, target string) error {
 	c, err := config.Load(pName)
 	if err != nil {
 		klog.Errorf("Failed to load profile %q: %v", pName, err)
-		return errors.Wrapf(err, "error loading config for profile :%v", pName)
+		return fmt.Errorf("error loading config for profile :%v: %w", pName, err)
 	}
 
 	for _, n := range c.Nodes {
@@ -899,7 +899,7 @@ func TagImage(profile *config.Profile, source string, target string) error {
 			}
 			crMgr, err := cruntime.New(cruntime.Config{Type: c.KubernetesConfig.ContainerRuntime, Runner: runner})
 			if err != nil {
-				return errors.Wrap(err, "error creating container runtime")
+				return fmt.Errorf("error creating container runtime: %w", err)
 			}
 			err = crMgr.TagImage(source, target)
 			if err != nil {
@@ -934,17 +934,17 @@ func pushImages(crMgr cruntime.Manager, imgs []string) error {
 		})
 	}
 	if err := g.Wait(); err != nil {
-		return errors.Wrap(err, "error pushing images")
+		return fmt.Errorf("error pushing images: %w", err)
 	}
 	klog.Infoln("Successfully pushed images")
 	return nil
 }
 
 // PushImages push images on all nodes in profile
-func PushImages(images []string, profile *config.Profile) error {
-	api, err := NewAPIClient()
+func PushImages(images []string, profile *config.Profile, options *run.CommandOptions) error {
+	api, err := NewAPIClient(options)
 	if err != nil {
-		return errors.Wrap(err, "error creating api client")
+		return fmt.Errorf("error creating api client: %w", err)
 	}
 	defer api.Close()
 
@@ -956,7 +956,7 @@ func PushImages(images []string, profile *config.Profile) error {
 	c, err := config.Load(pName)
 	if err != nil {
 		klog.Errorf("Failed to load profile %q: %v", pName, err)
-		return errors.Wrapf(err, "error loading config for profile :%v", pName)
+		return fmt.Errorf("error loading config for profile :%v: %w", pName, err)
 	}
 
 	for _, n := range c.Nodes {
@@ -980,7 +980,7 @@ func PushImages(images []string, profile *config.Profile) error {
 			}
 			crMgr, err := cruntime.New(cruntime.Config{Type: c.KubernetesConfig.ContainerRuntime, Runner: runner})
 			if err != nil {
-				return errors.Wrap(err, "error creating container runtime")
+				return fmt.Errorf("error creating container runtime: %w", err)
 			}
 			err = pushImages(crMgr, images)
 			if err != nil {
