@@ -25,31 +25,32 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/docker/machine/libmachine"
-	"github.com/docker/machine/libmachine/auth"
-	"github.com/docker/machine/libmachine/cert"
-	"github.com/docker/machine/libmachine/check"
-	"github.com/docker/machine/libmachine/drivers"
-	"github.com/docker/machine/libmachine/drivers/plugin"
-	"github.com/docker/machine/libmachine/drivers/plugin/localbinary"
-	"github.com/docker/machine/libmachine/engine"
-	"github.com/docker/machine/libmachine/host"
-	"github.com/docker/machine/libmachine/mcnutils"
-	"github.com/docker/machine/libmachine/persist"
-	lmssh "github.com/docker/machine/libmachine/ssh"
-	"github.com/docker/machine/libmachine/state"
-	"github.com/docker/machine/libmachine/swarm"
-	"github.com/docker/machine/libmachine/version"
-	"github.com/juju/fslock"
-	"github.com/pkg/errors"
+	"github.com/gofrs/flock"
 	"k8s.io/klog/v2"
+	"k8s.io/minikube/pkg/libmachine"
+	"k8s.io/minikube/pkg/libmachine/auth"
+	"k8s.io/minikube/pkg/libmachine/cert"
+	"k8s.io/minikube/pkg/libmachine/check"
+	"k8s.io/minikube/pkg/libmachine/drivers"
+	"k8s.io/minikube/pkg/libmachine/drivers/plugin"
+	"k8s.io/minikube/pkg/libmachine/drivers/plugin/localbinary"
+	"k8s.io/minikube/pkg/libmachine/engine"
+	"k8s.io/minikube/pkg/libmachine/host"
+	"k8s.io/minikube/pkg/libmachine/mcnutils"
+	"k8s.io/minikube/pkg/libmachine/persist"
+	lmssh "k8s.io/minikube/pkg/libmachine/ssh"
+	"k8s.io/minikube/pkg/libmachine/state"
+	"k8s.io/minikube/pkg/libmachine/swarm"
+	"k8s.io/minikube/pkg/libmachine/version"
 	"k8s.io/minikube/pkg/minikube/command"
+	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/driver"
 	"k8s.io/minikube/pkg/minikube/exit"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/out"
 	"k8s.io/minikube/pkg/minikube/reason"
 	"k8s.io/minikube/pkg/minikube/registry"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
 // NewRPCClient gets a new client.
@@ -60,7 +61,7 @@ func NewRPCClient(storePath, certsDir string) libmachine.API {
 }
 
 // NewAPIClient gets a new client.
-func NewAPIClient(miniHome ...string) (libmachine.API, error) {
+func NewAPIClient(options *run.CommandOptions, miniHome ...string) (libmachine.API, error) {
 	storePath := localpath.MiniPath()
 	if len(miniHome) > 0 {
 		storePath = miniHome[0]
@@ -68,11 +69,12 @@ func NewAPIClient(miniHome ...string) (libmachine.API, error) {
 	certsDir := localpath.MakeMiniPath("certs")
 
 	return &LocalClient{
-		certsDir:     certsDir,
-		storePath:    storePath,
-		Filestore:    persist.NewFilestore(storePath, certsDir, certsDir),
-		legacyClient: NewRPCClient(storePath, certsDir),
-		flock:        fslock.New(localpath.MakeMiniPath("machine_client.lock")),
+		certsDir:       certsDir,
+		storePath:      storePath,
+		Filestore:      persist.NewFilestore(storePath, certsDir, certsDir),
+		legacyClient:   NewRPCClient(storePath, certsDir),
+		flock:          flock.New(filepath.Join(storePath, "machine_client.lock")),
+		commandOptions: options,
 	}, nil
 }
 
@@ -83,7 +85,10 @@ type LocalClient struct {
 	storePath string
 	*persist.Filestore
 	legacyClient libmachine.API
-	flock        *fslock.Lock
+	flock        *flock.Flock
+	// TODO: Consider removing when libmachine API is part of minikube:
+	// https://github.com/kubernetes/minikube/issues/21789
+	commandOptions *run.CommandOptions
 }
 
 // NewHost creates a new Host
@@ -95,10 +100,10 @@ func (api *LocalClient) NewHost(drvName string, rawDriver []byte) (*host.Host, e
 	if def.Init == nil {
 		return api.legacyClient.NewHost(drvName, rawDriver)
 	}
-	d := def.Init()
+	d := def.Init(api.commandOptions)
 	err := json.Unmarshal(rawDriver, d)
 	if err != nil {
-		return nil, errors.Wrapf(err, "Error getting driver %s", string(rawDriver))
+		return nil, fmt.Errorf("Error getting driver %s: %w", string(rawDriver), err)
 	}
 
 	return &host.Host{
@@ -129,7 +134,7 @@ func (api *LocalClient) NewHost(drvName string, rawDriver []byte) (*host.Host, e
 func (api *LocalClient) Load(name string) (*host.Host, error) {
 	h, err := api.Filestore.Load(name)
 	if err != nil {
-		return nil, errors.Wrapf(err, "filestore %q", name)
+		return nil, fmt.Errorf("filestore %q: %w", name, err)
 	}
 
 	def := registry.Driver(h.DriverName)
@@ -139,7 +144,7 @@ func (api *LocalClient) Load(name string) (*host.Host, error) {
 	if def.Init == nil {
 		return api.legacyClient.Load(name)
 	}
-	h.Driver = def.Init()
+	h.Driver = def.Init(api.commandOptions)
 	return h, json.Unmarshal(h.RawDriver, h.Driver)
 }
 
@@ -187,20 +192,7 @@ func (api *LocalClient) Create(h *host.Host) error {
 		{
 			"bootstrapping certificates",
 			func() error {
-				// Lock is needed to avoid race condition in parallel Docker-Env test because issue #10107.
-				// CA cert and client cert should be generated atomically, otherwise might cause bad certificate error.
-				lockErr := api.flock.LockWithTimeout(time.Second * 5)
-				if lockErr != nil {
-					return fmt.Errorf("failed to acquire bootstrap client lock: %v", lockErr)
-				}
-				defer func() {
-					lockErr = api.flock.Unlock()
-					if lockErr != nil {
-						klog.Errorf("failed to release bootstrap cert client lock: %v", lockErr.Error())
-					}
-				}()
-				certErr := cert.BootstrapCertificates(h.AuthOptions())
-				return certErr
+				return api.bootstrapCertificatesWithLock(h)
 			},
 		},
 		{
@@ -240,19 +232,55 @@ func (api *LocalClient) Create(h *host.Host) error {
 
 	for _, step := range steps {
 		if err := step.f(); err != nil {
-			return errors.Wrap(err, step.name)
+			return fmt.Errorf("%s: %w", step.name, err)
 		}
 	}
 
 	return nil
 }
 
+func (api *LocalClient) bootstrapCertificatesWithLock(h *host.Host) error {
+	// Lock is needed to avoid race condition in parallel Docker-Env test because issue #10107.
+	// CA cert and client cert should be generated atomically, otherwise might cause bad certificate error.
+	timeout := time.Second * 5
+	start := time.Now()
+	var lockErr error
+	// gofrs/flock does not support LockWithTimeout, so we implement it manually with a retry loop.
+	for {
+		var locked bool
+		locked, lockErr = api.flock.TryLock()
+		if lockErr != nil {
+			break
+		}
+		if locked {
+			break
+		}
+		if time.Since(start) > timeout {
+			lockErr = fmt.Errorf("timeout acquiring lock")
+			break
+		}
+		time.Sleep(constants.LockRetryInterval)
+	}
+
+	if lockErr != nil {
+		return fmt.Errorf("failed to acquire bootstrap client lock: %v", lockErr)
+	}
+	defer func() {
+		lockErr = api.flock.Unlock()
+		if lockErr != nil {
+			klog.Errorf("failed to release bootstrap cert client lock: %v", lockErr.Error())
+		}
+	}()
+	certErr := cert.BootstrapCertificates(h.AuthOptions())
+	return certErr
+}
+
 // StartDriver starts the driver
-func StartDriver() {
+func StartDriver(options *run.CommandOptions) {
 	cert.SetCertGenerator(&CertGenerator{})
 	check.DefaultConnChecker = &ConnChecker{}
 	if os.Getenv(localbinary.PluginEnvKey) == localbinary.PluginEnvVal {
-		registerDriver(os.Getenv(localbinary.PluginEnvDriverName))
+		registerDriver(os.Getenv(localbinary.PluginEnvDriverName), options)
 	}
 
 	localbinary.CurrentBinaryIsDockerMachine = true
@@ -296,10 +324,10 @@ func (cg *CertGenerator) ValidateCertificate(addr string, authOptions *auth.Opti
 	return true, nil
 }
 
-func registerDriver(drvName string) {
+func registerDriver(drvName string, options *run.CommandOptions) {
 	def := registry.Driver(drvName)
 	if def.Empty() {
 		exit.Message(reason.Usage, "unsupported or missing driver: {{.name}}", out.V{"name": drvName})
 	}
-	plugin.RegisterDriver(def.Init())
+	plugin.RegisterDriver(def.Init(options))
 }
