@@ -137,6 +137,12 @@ func TestAssetsFromDir(t *testing.T) {
 			for _, actualFile := range actualFiles {
 				got[actualFile.GetSourcePath()] = actualFile.GetTargetDir()
 			}
+			// close any open file handles returned by assetsFromDir so Windows can clean up the temp dir
+			for _, actualFile := range actualFiles {
+				if c, ok := actualFile.(interface{ Close() error }); ok {
+					_ = c.Close()
+				}
+			}
 			if diff := cmp.Diff(want, got); diff != "" {
 				t.Errorf("files differ: (-want +got)\n%s", diff)
 			}
