@@ -29,10 +29,9 @@ import (
 	"sync"
 	"time"
 
+	"errors"
+
 	"github.com/blang/semver/v4"
-	"github.com/docker/machine/libmachine"
-	"github.com/docker/machine/libmachine/host"
-	"github.com/pkg/errors"
 	"github.com/spf13/viper"
 	"golang.org/x/sync/errgroup"
 	meta "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -41,6 +40,8 @@ import (
 	"k8s.io/minikube/pkg/addons"
 	"k8s.io/minikube/pkg/drivers/kic/oci"
 	"k8s.io/minikube/pkg/kapi"
+	"k8s.io/minikube/pkg/libmachine"
+	"k8s.io/minikube/pkg/libmachine/host"
 	"k8s.io/minikube/pkg/minikube/bootstrapper"
 	"k8s.io/minikube/pkg/minikube/bootstrapper/bsutil"
 	"k8s.io/minikube/pkg/minikube/bootstrapper/images"
@@ -64,6 +65,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/proxy"
 	"k8s.io/minikube/pkg/minikube/reason"
 	"k8s.io/minikube/pkg/minikube/registry"
+	"k8s.io/minikube/pkg/minikube/run"
 	"k8s.io/minikube/pkg/minikube/style"
 	"k8s.io/minikube/pkg/minikube/vmpath"
 	"k8s.io/minikube/pkg/network"
@@ -92,7 +94,7 @@ type Starter struct {
 }
 
 // Start spins up a guest and starts the Kubernetes node.
-func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
+func Start(starter Starter, options *run.CommandOptions) (*kubeconfig.Settings, error) { // nolint:gocyclo
 	var wg sync.WaitGroup
 	stopk8s, err := handleNoKubernetes(starter)
 	if err != nil {
@@ -113,7 +115,7 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 
 	sv, err := util.ParseKubernetesVersion(starter.Node.KubernetesVersion)
 	if err != nil {
-		return nil, errors.Wrap(err, "Failed to parse Kubernetes version")
+		return nil, fmt.Errorf("Failed to parse Kubernetes version: %w", err)
 	}
 
 	// configure the runtime (docker, containerd, crio)
@@ -138,7 +140,7 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 	var bs bootstrapper.Bootstrapper
 	if config.IsPrimaryControlPlane(*starter.Cfg, *starter.Node) {
 		// [re]start primary control-plane node
-		kcs, bs, err = startPrimaryControlPlane(starter, cr)
+		kcs, bs, err = startPrimaryControlPlane(starter, cr, options)
 		if err != nil {
 			return nil, err
 		}
@@ -165,17 +167,17 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 	} else {
 		bs, err = cluster.Bootstrapper(starter.MachineAPI, viper.GetString(cmdcfg.Bootstrapper), *starter.Cfg, starter.Runner)
 		if err != nil {
-			return nil, errors.Wrap(err, "Failed to get bootstrapper")
+			return nil, fmt.Errorf("Failed to get bootstrapper: %w", err)
 		}
 
 		// for ha (multi-control plane) cluster, use already running control-plane node to copy over certs to this secondary control-plane node
-		cpr := mustload.Running(starter.Cfg.Name).CP.Runner
+		cpr := mustload.Running(starter.Cfg.Name, options).CP.Runner
 		if err = bs.SetupCerts(*starter.Cfg, *starter.Node, cpr); err != nil {
-			return nil, errors.Wrap(err, "setting up certs")
+			return nil, fmt.Errorf("setting up certs: %w", err)
 		}
 
 		if err := bs.UpdateNode(*starter.Cfg, *starter.Node, cr); err != nil {
-			return nil, errors.Wrap(err, "update node")
+			return nil, fmt.Errorf("update node: %w", err)
 		}
 
 		// join cluster only on first node start
@@ -184,10 +186,10 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 			// make sure to use the command runner for the primary control plane to generate the join token
 			pcpBs, err := cluster.ControlPlaneBootstrapper(starter.MachineAPI, starter.Cfg, viper.GetString(cmdcfg.Bootstrapper))
 			if err != nil {
-				return nil, errors.Wrap(err, "get primary control-plane bootstrapper")
+				return nil, fmt.Errorf("get primary control-plane bootstrapper: %w", err)
 			}
-			if err := joinCluster(starter, pcpBs, bs); err != nil {
-				return nil, errors.Wrap(err, "join node to cluster")
+			if err := joinCluster(starter, pcpBs, bs, options); err != nil {
+				return nil, fmt.Errorf("join node to cluster: %w", err)
 			}
 		}
 	}
@@ -201,7 +203,7 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 		if err != nil {
 			out.FailureT("Unable to load profile: {{.error}}", out.V{"error": err})
 		}
-		if err := CacheAndLoadImagesInConfig([]*config.Profile{profile}); err != nil {
+		if err := CacheAndLoadImagesInConfig([]*config.Profile{profile}, options); err != nil {
 			out.FailureT("Unable to push cached images: {{.error}}", out.V{"error": err})
 		}
 	}()
@@ -215,12 +217,12 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 		}
 		list := addons.ToEnable(starter.Cfg, starter.ExistingAddons, addonList)
 		wg.Add(1)
-		go addons.Enable(&wg, starter.Cfg, list, enabledAddons)
+		go addons.Enable(&wg, starter.Cfg, list, enabledAddons, options)
 	}
 
 	// discourage use of the virtualbox driver
 	if starter.Cfg.Driver == driver.VirtualBox && viper.GetBool(config.WantVirtualBoxDriverWarning) {
-		warnVirtualBox()
+		warnVirtualBox(options)
 	}
 
 	// special ops for "none" driver on control-plane node, like change minikube directory
@@ -234,7 +236,7 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 	} else {
 		klog.Infof("Will wait %s for node %+v", viper.GetDuration(waitTimeout), starter.Node)
 		if err := bs.WaitForNode(*starter.Cfg, *starter.Node, viper.GetDuration(waitTimeout)); err != nil {
-			return nil, errors.Wrapf(err, "wait %s for node", viper.GetDuration(waitTimeout))
+			return nil, fmt.Errorf("wait %s for node: %w", viper.GetDuration(waitTimeout), err)
 		}
 	}
 
@@ -245,10 +247,10 @@ func Start(starter Starter) (*kubeconfig.Settings, error) { // nolint:gocyclo
 	if starter.ExistingAddons != nil {
 		klog.Infof("waiting for cluster config update ...")
 		if ea, ok := <-enabledAddons; ok {
-			addons.UpdateConfigToEnable(starter.Cfg, ea)
+			addons.UpdateConfigToEnable(starter.Cfg, ea, options)
 		}
 	} else {
-		addons.UpdateConfigToDisable(starter.Cfg)
+		addons.UpdateConfigToDisable(starter.Cfg, options)
 	}
 
 	// Write enabled addons to the config before completion
@@ -274,7 +276,7 @@ func handleNoKubernetes(starter Starter) (bool, error) {
 }
 
 // startPrimaryControlPlane starts control-plane node.
-func startPrimaryControlPlane(starter Starter, cr cruntime.Manager) (*kubeconfig.Settings, bootstrapper.Bootstrapper, error) {
+func startPrimaryControlPlane(starter Starter, cr cruntime.Manager, options *run.CommandOptions) (*kubeconfig.Settings, bootstrapper.Bootstrapper, error) {
 	if !config.IsPrimaryControlPlane(*starter.Cfg, *starter.Node) {
 		return nil, nil, fmt.Errorf("node not marked as primary control-plane")
 	}
@@ -282,7 +284,7 @@ func startPrimaryControlPlane(starter Starter, cr cruntime.Manager) (*kubeconfig
 	if config.IsHA(*starter.Cfg) {
 		n, err := network.Inspect(starter.Node.IP)
 		if err != nil {
-			return nil, nil, errors.Wrapf(err, "inspect network")
+			return nil, nil, fmt.Errorf("inspect network: %w", err)
 		}
 		// update cluster config
 		starter.Cfg.KubernetesConfig.APIServerHAVIP = n.ClientMax // last available ip from node's subnet, should've been reserved already
@@ -294,10 +296,10 @@ func startPrimaryControlPlane(starter Starter, cr cruntime.Manager) (*kubeconfig
 	// setup kubeadm (must come after setupKubeconfig)
 	bs, err := setupKubeadm(starter.MachineAPI, *starter.Cfg, *starter.Node, starter.Runner)
 	if err != nil {
-		return nil, nil, errors.Wrap(err, "Failed to setup kubeadm")
+		return nil, nil, fmt.Errorf("Failed to setup kubeadm: %w", err)
 	}
 
-	if err := bs.StartCluster(*starter.Cfg); err != nil {
+	if err := bs.StartCluster(*starter.Cfg, options); err != nil {
 		ExitIfFatal(err, false)
 		out.LogEntries("Error starting cluster", err, logs.FindProblems(cr, bs, *starter.Cfg, starter.Runner))
 		return nil, bs, err
@@ -305,14 +307,14 @@ func startPrimaryControlPlane(starter Starter, cr cruntime.Manager) (*kubeconfig
 
 	// Write the kubeconfig to the file system after everything required (like certs) are created by the bootstrapper.
 	if err := kubeconfig.Update(kcs); err != nil {
-		return nil, bs, errors.Wrap(err, "Failed kubeconfig update")
+		return nil, bs, fmt.Errorf("Failed kubeconfig update: %w", err)
 	}
 
 	return kcs, bs, nil
 }
 
 // joinCluster adds new or prepares and then adds existing node to the cluster.
-func joinCluster(starter Starter, cpBs bootstrapper.Bootstrapper, bs bootstrapper.Bootstrapper) error {
+func joinCluster(starter Starter, cpBs bootstrapper.Bootstrapper, bs bootstrapper.Bootstrapper, options *run.CommandOptions) error {
 	start := time.Now()
 	klog.Infof("joinCluster: %+v", starter.Cfg)
 	defer func() {
@@ -328,7 +330,7 @@ func joinCluster(starter Starter, cpBs bootstrapper.Bootstrapper, bs bootstrappe
 	// You must delete the existing Node or change the name of this new joining Node"
 	if starter.PreExists {
 		klog.Infof("removing existing %s node %q before attempting to rejoin cluster: %+v", role, starter.Node.Name, starter.Node)
-		if _, err := teardown(*starter.Cfg, starter.Node.Name); err != nil {
+		if _, err := teardown(*starter.Cfg, starter.Node.Name, options); err != nil {
 			klog.Errorf("error removing existing %s node %q before rejoining cluster, will continue anyway: %v", role, starter.Node.Name, err)
 		}
 		klog.Infof("successfully removed existing %s node %q from cluster: %+v", role, starter.Node.Name, starter.Node)
@@ -346,7 +348,7 @@ func joinCluster(starter Starter, cpBs bootstrapper.Bootstrapper, bs bootstrappe
 
 			// reset node to revert any changes made by previous kubeadm init/join
 			klog.Infof("resetting %s node %q before attempting to rejoin cluster...", role, starter.Node.Name)
-			if _, err := starter.Runner.RunCmd(exec.Command("/bin/bash", "-c", fmt.Sprintf("%s reset --force", bsutil.InvokeKubeadm(starter.Cfg.KubernetesConfig.KubernetesVersion)))); err != nil {
+			if _, err := starter.Runner.RunCmd(exec.Command("sudo", "/bin/bash", "-c", fmt.Sprintf("%s reset --force", bsutil.KubeadmCmdWithPath(starter.Cfg.KubernetesConfig.KubernetesVersion)))); err != nil {
 				klog.Infof("kubeadm reset failed, continuing anyway: %v", err)
 			} else {
 				klog.Infof("successfully reset %s node %q", role, starter.Node.Name)
@@ -367,7 +369,7 @@ func joinCluster(starter Starter, cpBs bootstrapper.Bootstrapper, bs bootstrappe
 }
 
 // Provision provisions the machine/container for the node
-func Provision(cc *config.ClusterConfig, n *config.Node, delOnFail bool) (command.Runner, bool, libmachine.API, *host.Host, error) {
+func Provision(cc *config.ClusterConfig, n *config.Node, delOnFail bool, options *run.CommandOptions) (command.Runner, bool, libmachine.API, *host.Host, error) {
 	register.Reg.SetStep(register.StartingNode)
 	name := config.MachineName(*cc, *n)
 
@@ -386,7 +388,7 @@ func Provision(cc *config.ClusterConfig, n *config.Node, delOnFail bool) (comman
 	}
 
 	if driver.IsKIC(cc.Driver) {
-		beginDownloadKicBaseImage(&kicGroup, cc, viper.GetBool("download-only"))
+		beginDownloadKicBaseImage(&kicGroup, cc, options.DownloadOnly)
 	}
 
 	if !driver.BareMetal(cc.Driver) {
@@ -396,15 +398,15 @@ func Provision(cc *config.ClusterConfig, n *config.Node, delOnFail bool) (comman
 	// Abstraction leakage alert: startHost requires the config to be saved, to satisfy pkg/provision/buildroot.
 	// Hence, SaveProfile must be called before startHost, and again afterwards when we know the IP.
 	if err := config.SaveProfile(viper.GetString(config.ProfileName), cc); err != nil {
-		return nil, false, nil, nil, errors.Wrap(err, "Failed to save config")
+		return nil, false, nil, nil, fmt.Errorf("Failed to save config: %w", err)
 	}
 
-	handleDownloadOnly(&cacheGroup, &kicGroup, n.KubernetesVersion, cc.KubernetesConfig.ContainerRuntime, cc.Driver)
+	handleDownloadOnly(&cacheGroup, &kicGroup, n.KubernetesVersion, cc.KubernetesConfig.ContainerRuntime, cc.Driver, options)
 	if driver.IsKIC(cc.Driver) {
 		waitDownloadKicBaseImage(&kicGroup)
 	}
 
-	return startMachine(cc, n, delOnFail)
+	return startMachine(cc, n, delOnFail, options)
 }
 
 // ConfigureRuntimes does what needs to happen to get a runtime going.
@@ -507,8 +509,18 @@ func cgroupDriver(cc config.ClusterConfig) string {
 		return constants.SystemdCgroupDriver
 	}
 
-	// vm driver uses iso that boots with cgroupfs cgroup driver by default atm (keep in sync!)
+	// VM driver supports both cgroup v1 and v2.
+	// On systemd-based systems (like Minikube ISO), systemd manages the single unified cgroup v2 hierarchy.
+	// Using cgroupfs with v2 would cause conflicts as two entities (systemd and runtime) try to manage the same hierarchy.
+	// Therefore, we default to the systemd driver for v2 to ensure stability and avoid conflicts.
 	if driver.IsVM(cc.Driver) {
+		// TODO, if system doesnt support cgroup v2, then use cgroupfs #22321
+		if ver, err := util.ParseKubernetesVersion(cc.KubernetesConfig.KubernetesVersion); err == nil {
+			if ver.GTE(semver.MustParse("1.22.0")) {
+				klog.Infof("Kubernetes %s+ detected, using %q cgroup driver", ver.String(), constants.SystemdCgroupDriver)
+				return constants.SystemdCgroupDriver
+			}
+		}
 		return constants.CgroupfsCgroupDriver
 	}
 
@@ -654,29 +666,29 @@ func setupKubeconfig(h host.Host, cc config.ClusterConfig, n config.Node, cluste
 }
 
 // StartMachine starts a VM
-func startMachine(cfg *config.ClusterConfig, node *config.Node, delOnFail bool) (runner command.Runner, preExists bool, machineAPI libmachine.API, hostInfo *host.Host, err error) {
-	m, err := machine.NewAPIClient()
+func startMachine(cfg *config.ClusterConfig, node *config.Node, delOnFail bool, options *run.CommandOptions) (runner command.Runner, preExists bool, machineAPI libmachine.API, hostInfo *host.Host, err error) {
+	m, err := machine.NewAPIClient(options)
 	if err != nil {
-		return runner, preExists, m, hostInfo, errors.Wrap(err, "Failed to get machine client")
+		return runner, preExists, m, hostInfo, fmt.Errorf("Failed to get machine client: %w", err)
 	}
 	hostInfo, preExists, err = startHostInternal(m, cfg, node, delOnFail)
 	if err != nil {
-		return runner, preExists, m, hostInfo, errors.Wrap(err, "Failed to start host")
+		return runner, preExists, m, hostInfo, fmt.Errorf("Failed to start host: %w", err)
 	}
 	runner, err = machine.CommandRunner(hostInfo)
 	if err != nil {
-		return runner, preExists, m, hostInfo, errors.Wrap(err, "Failed to get command runner")
+		return runner, preExists, m, hostInfo, fmt.Errorf("Failed to get command runner: %w", err)
 	}
 
 	ip, err := validateNetwork(hostInfo, runner, cfg.KubernetesConfig.ImageRepository)
 	if err != nil {
-		return runner, preExists, m, hostInfo, errors.Wrap(err, "Failed to validate network")
+		return runner, preExists, m, hostInfo, fmt.Errorf("Failed to validate network: %w", err)
 	}
 
 	if driver.IsQEMU(hostInfo.Driver.DriverName()) && network.IsBuiltinQEMU(cfg.Network) {
 		apiServerPort, err := getPort()
 		if err != nil {
-			return runner, preExists, m, hostInfo, errors.Wrap(err, "Failed to find apiserver port")
+			return runner, preExists, m, hostInfo, fmt.Errorf("Failed to find apiserver port: %w", err)
 		}
 		cfg.APIServerPort = apiServerPort
 	}
@@ -699,7 +711,7 @@ func getPort() (int, error) {
 
 	l, err := net.ListenTCP("tcp", addr)
 	if err != nil {
-		return -1, errors.Errorf("Error accessing port %d", addr.Port)
+		return -1, fmt.Errorf("Error accessing port %d", addr.Port)
 	}
 	defer l.Close()
 	return l.Addr().(*net.TCPAddr).Port, nil
@@ -720,7 +732,8 @@ func startHostInternal(api libmachine.API, cc *config.ClusterConfig, n *config.N
 		}
 	}
 
-	if err, ff := errors.Cause(err).(*oci.FailFastError); ff {
+	var ff *oci.FailFastError
+	if errors.As(err, &ff) {
 		klog.Infof("will skip retrying to create machine because error is not retriable: %v", err)
 		return hostInfo, exists, err
 	}
@@ -859,11 +872,17 @@ func tryRegistry(r command.Runner, driverName, imageRepository, ip string) {
 
 	curlTarget := fmt.Sprintf("https://%s/", imageRepository)
 	opts = append(opts, curlTarget)
-	exe := "curl"
+
+	// Always use the 'curl' binary inside the guest. On Windows hosts,
+	// PowerShell exposes an alias which can interfere with the host check,
+	// so use 'curl.exe' for the host-run check only.
+	cmd := exec.Command("curl", opts...)
+	hostExe := "curl"
 	if runtime.GOOS == "windows" {
-		exe = "curl.exe"
+		hostExe = "curl.exe"
 	}
-	cmd := exec.Command(exe, opts...)
+	cmdHost := exec.Command(hostExe, opts...)
+
 	if rr, err := r.RunCmd(cmd); err != nil {
 		klog.Warningf("%s failed: %v", rr.Args, err)
 
@@ -882,7 +901,7 @@ func tryRegistry(r command.Runner, driverName, imageRepository, ip string) {
 		// on the ssh driver is not helpful.
 		warning := "Failing to connect to {{.curlTarget}} from inside the minikube {{.type}}"
 		if !driver.IsNone(driverName) && !driver.IsSSH(driverName) {
-			if err := cmd.Run(); err != nil {
+			if err := cmdHost.Run(); err != nil {
 				// both inside and outside failed
 				warning = "Failing to connect to {{.curlTarget}} from both inside the minikube {{.type}} and host machine"
 			}
@@ -979,9 +998,9 @@ func addCoreDNSEntry(runner command.Runner, name, ip string, cc config.ClusterCo
 }
 
 // prints a warning to the console against the use of the 'virtualbox' driver, if alternatives are available and healthy
-func warnVirtualBox() {
+func warnVirtualBox(options *run.CommandOptions) {
 	var altDriverList strings.Builder
-	for _, choice := range driver.Choices(true) {
+	for _, choice := range driver.Choices(true, options) {
 		if !driver.IsVirtualBox(choice.Name) && choice.Priority != registry.Discouraged && choice.State.Installed && choice.State.Healthy {
 			altDriverList.WriteString(fmt.Sprintf("\n\t- %s", choice.Name))
 		}
