@@ -25,15 +25,15 @@ import (
 	"strings"
 	"time"
 
-	"github.com/docker/machine/drivers/hyperv"
-	"github.com/docker/machine/libmachine/drivers"
-	"github.com/pkg/errors"
+	"k8s.io/minikube/pkg/libmachine/drivers"
 
+	"k8s.io/minikube/pkg/drivers/hyperv"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/download"
 	"k8s.io/minikube/pkg/minikube/driver"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/registry"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
 const (
@@ -44,7 +44,7 @@ const (
 func init() {
 	if err := registry.Register(registry.DriverDef{
 		Name:     driver.HyperV,
-		Init:     func() drivers.Driver { return hyperv.NewDriver("", "") },
+		Init:     func(_ *run.CommandOptions) drivers.Driver { return hyperv.NewDriver("", "") },
 		Config:   configure,
 		Status:   status,
 		Default:  true,
@@ -61,7 +61,7 @@ func configure(cfg config.ClusterConfig, n config.Node) (interface{}, error) {
 	if d.VSwitch == "" && cfg.HypervUseExternalSwitch {
 		switchName, adapter, err := chooseSwitch(cfg.HypervExternalAdapter)
 		if err != nil {
-			return nil, errors.Wrapf(err, "failed to choose switch for Hyper-V driver")
+			return nil, fmt.Errorf("failed to choose switch for Hyper-V driver: %w", err)
 		}
 		if cfg.HypervExternalAdapter == "" && switchName == "" {
 			// create a switch on the returned adapter
@@ -81,7 +81,7 @@ func configure(cfg config.ClusterConfig, n config.Node) (interface{}, error) {
 	return d, nil
 }
 
-func status() registry.State {
+func status(_ *run.CommandOptions) registry.State {
 	path, err := exec.LookPath("powershell")
 	if err != nil {
 		return registry.State{Error: err}
