@@ -22,14 +22,14 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/docker/machine/libmachine/drivers"
-	"github.com/pkg/errors"
+	"k8s.io/minikube/pkg/libmachine/drivers"
 
 	"k8s.io/minikube/pkg/drivers/ssh"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/driver"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/registry"
+	"k8s.io/minikube/pkg/minikube/run"
 )
 
 func init() {
@@ -40,7 +40,7 @@ func init() {
 		Status:   status,
 		Default:  false, // requires external VM
 		Priority: registry.Discouraged,
-		Init:     func() drivers.Driver { return ssh.NewDriver(ssh.Config{}) },
+		Init:     func(_ *run.CommandOptions) drivers.Driver { return ssh.NewDriver(ssh.Config{}) },
 	})
 	if err != nil {
 		panic(fmt.Sprintf("unable to register: %v", err))
@@ -55,13 +55,13 @@ func configure(cc config.ClusterConfig, n config.Node) (interface{}, error) {
 	})
 
 	if cc.SSHIPAddress == "" {
-		return nil, errors.Errorf("please provide an IP address")
+		return nil, fmt.Errorf("please provide an IP address")
 	}
 
 	// We don't want the API server listening on loopback interface,
 	// even if we might use a tunneled VM port for the SSH service
 	if cc.SSHIPAddress == "127.0.0.1" || cc.SSHIPAddress == "localhost" {
-		return nil, errors.Errorf("please provide real IP address")
+		return nil, fmt.Errorf("please provide real IP address")
 	}
 
 	d.IPAddress = cc.SSHIPAddress
@@ -70,7 +70,7 @@ func configure(cc config.ClusterConfig, n config.Node) (interface{}, error) {
 	if strings.HasPrefix(cc.SSHKey, "~") {
 		dirname, err := os.UserHomeDir()
 		if err != nil {
-			return nil, errors.Errorf("Error determining path to ssh key: %v", err)
+			return nil, fmt.Errorf("Error determining path to ssh key: %v", err)
 		}
 		d.SSHKey = filepath.Join(dirname, cc.SSHKey[1:])
 	} else {
@@ -82,6 +82,6 @@ func configure(cc config.ClusterConfig, n config.Node) (interface{}, error) {
 	return d, nil
 }
 
-func status() registry.State {
+func status(_ *run.CommandOptions) registry.State {
 	return registry.State{Installed: true, Healthy: true}
 }
