@@ -21,15 +21,15 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"path/filepath"
 	"reflect"
 	"strings"
 	"testing"
 	"text/template"
 	"time"
 
-	"github.com/docker/machine/libmachine"
-	"github.com/docker/machine/libmachine/host"
-	"github.com/pkg/errors"
+	"errors"
+
 	"github.com/spf13/viper"
 	core "k8s.io/api/core/v1"
 	discoveryv1 "k8s.io/api/discovery/v1"
@@ -43,6 +43,8 @@ import (
 	typed_discovery "k8s.io/client-go/kubernetes/typed/discovery/v1"
 	"k8s.io/client-go/rest"
 	testing_fake "k8s.io/client-go/testing"
+	"k8s.io/minikube/pkg/libmachine"
+	"k8s.io/minikube/pkg/libmachine/host"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/tests"
@@ -349,7 +351,7 @@ func (s *MockServiceInterface) List(_ context.Context, opts meta.ListOptions) (*
 
 func (s *MockServiceInterface) Get(_ context.Context, name string, _ meta.GetOptions) (*core.Service, error) {
 	for _, svc := range s.ServiceList.Items {
-		if svc.ObjectMeta.Name == name {
+		if svc.Name == name {
 			return &svc, nil
 		}
 	}
@@ -712,45 +714,41 @@ preferences: {}
 users:
 - name: minikube
 `
-	var tests = []struct {
-		description    string
-		kubeconfigPath string
-		config         string
-		err            bool
+	tests := []struct {
+		description string
+		config      string
+		err         bool
 	}{
 		{
-			description:    "ok",
-			kubeconfigPath: "/tmp/kube_config",
-			config:         mockK8sConfig,
-			err:            false,
+			description: "ok",
+			config:      mockK8sConfig,
+			err:         false,
 		},
 		{
-			description:    "empty config",
-			kubeconfigPath: "/tmp/kube_config",
-			config:         "",
-			err:            true,
+			description: "empty config",
+			config:      "",
+			err:         true,
 		},
 		{
-			description:    "broken config",
-			kubeconfigPath: "/tmp/kube_config",
-			config:         "this**is&&not: yaml::valid: file",
-			err:            true,
+			description: "broken config",
+			config:      "this**is&&not: yaml::valid: file",
+			err:         true,
 		},
 	}
 
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
-			mockK8sConfigByte := []byte(test.config)
-			mockK8sConfigPath := test.kubeconfigPath
-			err := os.WriteFile(mockK8sConfigPath, mockK8sConfigByte, 0644)
-			defer os.Remove(mockK8sConfigPath)
-			if err != nil {
-				t.Fatalf("Unexpected error when writing to file %v. Error: %v", test.kubeconfigPath, err)
+			tmpDir := t.TempDir()
+			mockK8sConfigPath := filepath.Join(tmpDir, "kube_config")
+
+			if err := os.WriteFile(mockK8sConfigPath, []byte(test.config), 0600); err != nil {
+				t.Fatalf("failed to write kubeconfig: %v", err)
 			}
 			t.Setenv("KUBECONFIG", mockK8sConfigPath)
 
 			k8s := K8sClientGetter{}
-			_, err = k8s.GetCoreClient("minikube")
+			_, err := k8s.GetCoreClient("minikube")
+
 			if err != nil && !test.err {
 				t.Fatalf("GetCoreClient returned unexpected error: %v", err)
 			}
