@@ -77,12 +77,13 @@ func (t *routingTable) Check(route *Route) (exists bool, conflict string, overla
 	overlaps = []string{}
 	for _, tableLine := range *t {
 
-		if route.Equal(tableLine.route) {
+		switch {
+		case route.Equal(tableLine.route):
 			exists = true
-		} else if route.DestCIDR.String() == tableLine.route.DestCIDR.String() &&
-			route.Gateway.String() != tableLine.route.Gateway.String() {
+		case route.DestCIDR.String() == tableLine.route.DestCIDR.String() &&
+			route.Gateway.String() != tableLine.route.Gateway.String():
 			conflict = tableLine.line
-		} else if route.DestCIDR.Contains(tableLine.route.DestCIDR.IP) || tableLine.route.DestCIDR.Contains(route.DestCIDR.IP) {
+		case route.DestCIDR.Contains(tableLine.route.DestCIDR.IP) || tableLine.route.DestCIDR.Contains(route.DestCIDR.IP):
 			overlaps = append(overlaps, tableLine.line)
 		}
 	}
