@@ -23,7 +23,7 @@ import (
 	"os"
 	"time"
 
-	"github.com/pkg/errors"
+	"errors"
 
 	"k8s.io/klog/v2"
 )
