@@ -21,7 +21,6 @@ package util
 import (
 	"os"
 	"os/user"
-	"runtime"
 	"syscall"
 	"testing"
 
@@ -125,10 +124,8 @@ func TestChownR(t *testing.T) {
 	}
 }
 
+// this test runs on non-windows because of the build tag at the top of the file
 func TestMaybeChownDirRecursiveToMinikubeUser(t *testing.T) {
-	if runtime.GOOS == "windows" {
-		t.Skip("skipping on windows")
-	}
 
 	testDir := t.TempDir()
 	if _, err := os.Create(testDir + "/TestChownR"); nil != err {
