@@ -22,7 +22,6 @@ import (
 	"bufio"
 	"bytes"
 	"context"
-	"crypto/md5"
 	"crypto/sha256"
 	"encoding/json"
 	"fmt"
@@ -35,6 +34,7 @@ import (
 	"strings"
 	"testing"
 
+	"k8s.io/minikube/pkg/libmachine/mcnutils"
 	"k8s.io/minikube/pkg/minikube/bootstrapper/images"
 	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/download"
@@ -235,23 +235,19 @@ func TestDownloadOnlyKic(t *testing.T) {
 
 	// Make sure the downloaded image tarball exists
 	tarball := download.TarballPath(constants.DefaultKubernetesVersion, cRuntime)
-	contents, err := os.ReadFile(tarball)
+	fi, err := os.Stat(tarball)
 	if err != nil {
-		t.Errorf("failed to read tarball file %q: %v", tarball, err)
+		t.Errorf("expected tarball file %q to exist, but got error: %v", tarball, err)
+	} else {
+		const minSize int64 = 200 * 1024 * 1024 // 200 MB
+		if fi.Size() <= minSize {
+			t.Errorf("expected tarball file %q to be larger than 200MB (>%d bytes), got %d bytes", tarball, minSize, fi.Size())
+		}
 	}
 
 	if arm64Platform() {
 		t.Skip("Skip for arm64 platform. See https://github.com/kubernetes/minikube/issues/10144")
 	}
-	// Make sure it has the correct checksum
-	checksum := md5.Sum(contents)
-	remoteChecksum, err := os.ReadFile(download.PreloadChecksumPath(constants.DefaultKubernetesVersion, cRuntime))
-	if err != nil {
-		t.Errorf("failed to read checksum file %q : %v", download.PreloadChecksumPath(constants.DefaultKubernetesVersion, cRuntime), err)
-	}
-	if string(remoteChecksum) != string(checksum[:]) {
-		t.Errorf("failed to verify checksum. checksum of %q does not match remote checksum (%q != %q)", tarball, string(remoteChecksum), string(checksum[:]))
-	}
 }
 
 // createSha256File is a helper function which creates sha256 checksum file from given file
@@ -265,7 +261,7 @@ func createSha256File(filePath string) error {
 	}
 	defer f.Close()
 
-	_, err = f.WriteString(fmt.Sprintf("%x", sum[:]))
+	_, err = fmt.Fprintf(f, "%x", sum[:])
 	if err != nil {
 		return err
 	}
@@ -301,8 +297,16 @@ func TestBinaryMirror(t *testing.T) {
 	}
 
 	newBinaryPath := filepath.Join(newBinaryDir, binaryName)
+	// Usage of os.Rename might result in "invalid cross-device link" error if the files are not on the same partition.
+	// In that case, we fall back to copying the file.
 	if err := os.Rename(binaryPath, newBinaryPath); err != nil {
-		t.Errorf("Failed to move binary file: %+v", err)
+		t.Logf("os.Rename failed, falling back to copy (likely cross-device): %v", err)
+		if err := mcnutils.CopyFile(binaryPath, newBinaryPath); err != nil {
+			t.Fatalf("Failed to copy binary file: %v", err)
+		}
+		if err := os.Remove(binaryPath); err != nil {
+			t.Logf("Warning: Failed to remove original binary file: %v", err)
+		}
 	}
 	if err := createSha256File(newBinaryPath); err != nil {
 		t.Errorf("Failed to generate sha256 checksum file: %+v", err)
