@@ -27,6 +27,8 @@ import (
 	"regexp"
 	"strings"
 	"testing"
+
+	"k8s.io/minikube/pkg/minikube/constants"
 )
 
 // stderrAllow are regular expressions acceptable to find in normal stderr
@@ -52,6 +54,8 @@ var stderrAllow = []string{
 	// Warning of issues with specific Kubernetes versions
 	`Kubernetes .* has a known `,
 	`For more information, see`,
+	// warning about upcoming default container runtime change
+	regexp.QuoteMeta(constants.DefaultContainerRuntimeChangeWarning),
 }
 
 // stderrAllowRe combines rootCauses into a single regex
