@@ -252,7 +252,7 @@ func validateHAAddWorkerNode(ctx context.Context, t *testing.T, profile string)
 // validateHANodeLabels check if all node labels were configured correctly.
 func validateHANodeLabels(ctx context.Context, t *testing.T, profile string) {
 	// docs: Get the node labels from the cluster with `kubectl get nodes`
-	rr, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "get", "nodes", "-o", "jsonpath=[{range .items[*]}{.metadata.labels},{end}]"))
+	rr, err := Run(t, exec.CommandContext(ctx, KubectlBinary(), "--context", profile, "get", "nodes", "-o", "jsonpath=[{range .items[*]}{.metadata.labels},{end}]"))
 	if err != nil {
 		t.Errorf("failed to 'kubectl get nodes' with args %q: %v", rr.Command(), err)
 	}
@@ -447,7 +447,7 @@ func validateHARestartSecondaryNode(ctx context.Context, t *testing.T, profile s
 	}
 
 	// ensure kubectl can connect correctly
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "get", "nodes"))
+	rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "get", "nodes"))
 	if err != nil {
 		t.Fatalf("failed to kubectl get nodes. args %q : %v", rr.Command(), err)
 	}
@@ -510,7 +510,7 @@ func validateHADeleteSecondaryNode(ctx context.Context, t *testing.T, profile st
 	}
 
 	// ensure kubectl knows the node is gone
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "get", "nodes"))
+	rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "get", "nodes"))
 	if err != nil {
 		t.Fatalf("failed to run kubectl get nodes. args %q : %v", rr.Command(), err)
 	}
@@ -518,7 +518,7 @@ func validateHADeleteSecondaryNode(ctx context.Context, t *testing.T, profile st
 		t.Errorf("expected 3 nodes to be Ready, got %v", rr.Output())
 	}
 
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "get", "nodes", "-o", `go-template='{{range .items}}{{range .status.conditions}}{{if eq .type "Ready"}} {{.status}}{{"\n"}}{{end}}{{end}}{{end}}'`))
+	rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "get", "nodes", "-o", `go-template='{{range .items}}{{range .status.conditions}}{{if eq .type "Ready"}} {{.status}}{{"\n"}}{{end}}{{end}}{{end}}'`))
 	if err != nil {
 		t.Fatalf("failed to run kubectl get nodes. args %q : %v", rr.Command(), err)
 	}
@@ -583,7 +583,7 @@ func validateHARestartCluster(ctx context.Context, t *testing.T, profile string)
 	}
 
 	// ensure kubectl reports that all nodes are ready
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "get", "nodes"))
+	rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "get", "nodes"))
 	if err != nil {
 		t.Fatalf("failed to run kubectl get nodes. args %q : %v", rr.Command(), err)
 	}
@@ -591,7 +591,7 @@ func validateHARestartCluster(ctx context.Context, t *testing.T, profile string)
 		t.Errorf("expected 3 nodes to be Ready, got %v", rr.Output())
 	}
 
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "get", "nodes", "-o", `go-template='{{range .items}}{{range .status.conditions}}{{if eq .type "Ready"}} {{.status}}{{"\n"}}{{end}}{{end}}{{end}}'`))
+	rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "get", "nodes", "-o", `go-template='{{range .items}}{{range .status.conditions}}{{if eq .type "Ready"}} {{.status}}{{"\n"}}{{end}}{{end}}{{end}}'`))
 	if err != nil {
 		t.Fatalf("failed to run kubectl get nodes. args %q : %v", rr.Command(), err)
 	}
