@@ -32,20 +32,30 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"runtime"
 	"strconv"
 	"strings"
 	"testing"
 	"time"
 
-	"github.com/docker/machine/libmachine/state"
 	"github.com/google/go-cmp/cmp"
-	"github.com/shirou/gopsutil/v3/process"
+	"github.com/shirou/gopsutil/v4/process"
 	core "k8s.io/api/core/v1"
 	meta "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/minikube/pkg/kapi"
+	"k8s.io/minikube/pkg/libmachine/state"
+	"k8s.io/minikube/pkg/minikube/detect"
 )
 
+// KubectlBinary returns the name of the kubectl binary for the current OS
+func KubectlBinary() string {
+	if runtime.GOOS == "windows" {
+		return "kubectl.exe"
+	}
+	return "kubectl"
+}
+
 // RunResult stores the result of an cmd.Run call
 type RunResult struct {
 	Stdout   *bytes.Buffer
@@ -266,7 +276,7 @@ func PostMortemLogs(t *testing.T, profile string, multinode ...bool) {
 		}
 
 		// Get non-running pods. NOTE: This does not yet contain pods which are "running", but not "ready"
-		rr, rerr := Run(t, exec.Command("kubectl", "--context", profile, "get", "po", "-o=jsonpath={.items[*].metadata.name}", "-A", "--field-selector=status.phase!=Running"))
+		rr, rerr := Run(t, exec.Command(KubectlBinary(), "--context", profile, "get", "po", "-o=jsonpath={.items[*].metadata.name}", "-A", "--field-selector=status.phase!=Running"))
 		if rerr != nil {
 			t.Logf("%s: %v", rr.Command(), rerr)
 			return
@@ -282,7 +292,7 @@ func PostMortemLogs(t *testing.T, profile string, multinode ...bool) {
 		t.Logf("======> post-mortem[%s]: describe non-running pods <======", t.Name())
 
 		args := append([]string{"--context", profile, "describe", "pod"}, notRunning...)
-		rr, rerr = Run(t, exec.Command("kubectl", args...))
+		rr, rerr = Run(t, exec.Command(KubectlBinary(), args...))
 		if rerr != nil {
 			t.Logf("%s: %v", rr.Command(), rerr)
 			return
@@ -297,7 +307,7 @@ func PostMortemLogs(t *testing.T, profile string, multinode ...bool) {
 // podStatusMsg returns a human-readable pod status, for generating debug status
 func podStatusMsg(pod core.Pod) string {
 	var sb strings.Builder
-	sb.WriteString(fmt.Sprintf("%q [%s] %s", pod.ObjectMeta.GetName(), pod.ObjectMeta.GetUID(), pod.Status.Phase))
+	sb.WriteString(fmt.Sprintf("%q [%s] %s", pod.GetName(), pod.GetUID(), pod.Status.Phase))
 	for i, c := range pod.Status.Conditions {
 		if c.Reason != "" {
 			if i == 0 {
@@ -345,7 +355,7 @@ func PodWait(ctx context.Context, t *testing.T, profile string, ns string, selec
 		}
 
 		for _, pod := range pods.Items {
-			foundNames[pod.ObjectMeta.Name] = true
+			foundNames[pod.Name] = true
 			msg := podStatusMsg(pod)
 			// Prevent spamming logs with identical messages
 			if msg != lastMsg {
@@ -399,7 +409,7 @@ func PVCWait(ctx context.Context, t *testing.T, profile string, ns string, name
 	t.Logf("(dbg) %s: waiting %s for pvc %q in namespace %q ...", t.Name(), timeout, name, ns)
 
 	f := func(ctx context.Context) (bool, error) {
-		ret, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "get", "pvc", name, "-o", "jsonpath={.status.phase}", "-n", ns))
+		ret, err := Run(t, exec.CommandContext(ctx, KubectlBinary(), "--context", profile, "get", "pvc", name, "-o", "jsonpath={.status.phase}", "-n", ns))
 		if err != nil {
 			t.Logf("%s: WARNING: PVC get for %q %q returned: %v", t.Name(), ns, name, err)
 			return false, nil
@@ -424,7 +434,7 @@ func VolumeSnapshotWait(ctx context.Context, t *testing.T, profile string, ns st
 	t.Logf("(dbg) %s: waiting %s for volume snapshot %q in namespace %q ...", t.Name(), timeout, name, ns)
 
 	f := func(ctx context.Context) (bool, error) {
-		res, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "get", "volumesnapshot", name, "-o", "jsonpath={.status.readyToUse}", "-n", ns))
+		res, err := Run(t, exec.CommandContext(ctx, KubectlBinary(), "--context", profile, "get", "volumesnapshot", name, "-o", "jsonpath={.status.readyToUse}", "-n", ns))
 		if err != nil {
 			t.Logf("%s: WARNING: volume snapshot get for %q %q returned: %v", t.Name(), ns, name, err)
 			return false, nil
@@ -474,14 +484,14 @@ func showPodLogs(ctx context.Context, t *testing.T, profile string, ns string, n
 	t.Logf("%s: showing logs for failed pods as of %s", t.Name(), time.Now())
 
 	for _, name := range names {
-		rr, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "describe", "po", name, "-n", ns))
+		rr, err := Run(t, exec.CommandContext(ctx, KubectlBinary(), "--context", profile, "describe", "po", name, "-n", ns))
 		if err != nil {
 			t.Logf("%s: %v", rr.Command(), err)
 		} else {
 			t.Logf("(dbg) %s:\n%s", rr.Command(), rr.Stdout)
 		}
 
-		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "logs", name, "-n", ns))
+		rr, err = Run(t, exec.CommandContext(ctx, KubectlBinary(), "--context", profile, "logs", name, "-n", ns))
 		if err != nil {
 			t.Logf("%s: %v", rr.Command(), err)
 		} else {
@@ -704,3 +714,17 @@ func CopyDir(src, dst string) error {
 
 	return nil
 }
+
+// FailFast proactively stops the addon suite when Docker Hub is rate limited.
+func FailFastDockerHubRateLimited(t *testing.T) {
+	t.Helper()
+	remaining, err := detect.DockerHubRateLimitRemaining(t.Context())
+	if err != nil {
+		t.Logf("unable to check Docker Hub rate limit (continuing): %v", err)
+		return
+	}
+
+	if remaining <= 0 {
+		t.Fatalf("failing fast: Docker Hub rate limit reached (remaining=%d)", remaining)
+	}
+}
